@@ -5,6 +5,7 @@ import (
 	"testing"
 
 	"github.com/acorn-io/runtime/pkg/config"
+	"github.com/acorn-io/z"
 	kclient "sigs.k8s.io/controller-runtime/pkg/client"
 )
 
@@ -41,3 +42,30 @@ func EnableFeatureWithRestore(t *testing.T, ctx context.Context, kclient kclient
 		t.Fatal(err)
 	}
 }
+
+func SetIgnoreResourceRequirementsWithRestore(t *testing.T, ctx context.Context, kclient kclient.WithWatch) {
+	t.Helper()
+
+	cfg, err := config.Get(ctx, kclient)
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	state := z.Dereference(cfg.IgnoreResourceRequirements)
+
+	cfg.IgnoreResourceRequirements = z.Pointer(true)
+
+	t.Cleanup(func() {
+		cfg.IgnoreResourceRequirements = z.Pointer(state)
+
+		err = config.Set(ctx, kclient, cfg)
+		if err != nil {
+			t.Fatal(err)
+		}
+	})
+
+	err = config.Set(ctx, kclient, cfg)
+	if err != nil {
+		t.Fatal(err)
+	}
+}
