@@ -5,6 +5,7 @@ import (
 	"sort"
 	"strings"
 
+	"github.com/acorn-io/aml/pkg/jsonschema"
 	"golang.org/x/exp/slices"
 	rbacv1 "k8s.io/api/rbac/v1"
 )
@@ -49,6 +50,7 @@ type Build struct {
 	BaseImage          string            `json:"baseImage,omitempty"`
 	ContextDirs        map[string]string `json:"contextDirs,omitempty"`
 	BuildArgs          map[string]string `json:"buildArgs,omitempty"`
+	WatchFiles         []string          `json:"watchFiles,omitempty"`
 }
 
 func (in Build) BaseBuild() Build {
@@ -165,6 +167,7 @@ type VolumeMount struct {
 	Volume     string            `json:"volume,omitempty"`
 	SubPath    string            `json:"subPath,omitempty"`
 	ContextDir string            `json:"contextDir,omitempty"`
+	Preload    bool              `json:"preload,omitempty"`
 	Secret     VolumeSecretMount `json:"secret,omitempty"`
 }
 
@@ -238,6 +241,11 @@ type PolicyRule struct {
 	Scopes            []string `json:"scopes,omitempty"`
 }
 
+type UserContext struct {
+	UID int64 `json:"uid,omitempty"`
+	GID int64 `json:"gid,omitempty"`
+}
+
 func slicePermutation(in []string) (result [][]string) {
 	if len(in) == 0 {
 		return [][]string{nil}
@@ -629,6 +637,7 @@ type Container struct {
 	Files        Files                  `json:"files,omitempty"`
 	Image        string                 `json:"image,omitempty"`
 	Build        *Build                 `json:"build,omitempty"`
+	Src          string                 `json:"src,omitempty"`
 	Command      CommandSlice           `json:"command,omitempty"`
 	Interactive  bool                   `json:"interactive,omitempty"`
 	Entrypoint   CommandSlice           `json:"entrypoint,omitempty"`
@@ -640,6 +649,7 @@ type Container struct {
 	Permissions  *Permissions           `json:"permissions,omitempty"`
 	ComputeClass *string                `json:"class,omitempty"`
 	Memory       *int64                 `json:"memory,omitempty"`
+	UserContext  *UserContext           `json:"user,omitempty"`
 
 	// Metrics is available on containers and jobs, but not sidecars
 	Metrics MetricsDef `json:"metrics,omitempty"`
@@ -658,6 +668,9 @@ type Container struct {
 
 	// Sidecars are not available on sidecars
 	Sidecars map[string]Container `json:"sidecars,omitempty"`
+
+	// InputSchema is only available on function
+	InputSchema *jsonschema.Schema `json:"inputSchema,omitempty"`
 }
 
 type Image struct {
@@ -675,6 +688,7 @@ type AppSpec struct {
 	Info        string                   `json:"info,omitempty"`
 	Icon        string                   `json:"icon,omitempty"`
 	Containers  map[string]Container     `json:"containers,omitempty"`
+	Functions   map[string]Container     `json:"functions,omitempty"`
 	Jobs        map[string]Container     `json:"jobs,omitempty"`
 	Images      map[string]Image         `json:"images,omitempty"`
 	Volumes     map[string]VolumeRequest `json:"volumes,omitempty"`
@@ -682,8 +696,26 @@ type AppSpec struct {
 	Acorns      map[string]Acorn         `json:"acorns,omitempty"`
 	Routers     map[string]Router        `json:"routers,omitempty"`
 	Services    map[string]Service       `json:"services,omitempty"`
+	Assistants  map[string]Assistant     `json:"assistants,omitempty"`
 }
 
+type Assistant struct {
+	Labels       map[string]string  `json:"labels,omitempty"`
+	Annotations  map[string]string  `json:"annotations,omitempty"`
+	Name         string             `json:"name,omitempty"`
+	Description  string             `json:"description,omitempty"`
+	Prompts      Prompts            `json:"prompts,omitempty"`
+	Vision       bool               `json:"vision,omitempty"`
+	Model        string             `json:"model,omitempty"`
+	Dependencies Dependencies       `json:"tools,omitempty"`
+	InputSchema  *jsonschema.Schema `json:"inputSchema,omitempty"`
+	MaxTokens    int                `json:"maxTokens,omitempty"`
+	JSONResponse bool               `json:"jsonResponse,omitempty"`
+	Cache        *bool              `json:"cache,omitempty"`
+}
+
+type Prompts []string
+
 type Route struct {
 	Path              string   `json:"path,omitempty"`
 	TargetServiceName string   `json:"targetServiceName,omitempty"`
