@@ -11,6 +11,7 @@ var (
 type ContainerImageBuilderSpec struct {
 	Image string `json:"image,omitempty"`
 	Build *Build `json:"build,omitempty"`
+	Src   string `json:"src,omitempty"`
 	// Sidecars is only populated for non-sidecar containers
 	Sidecars map[string]ContainerImageBuilderSpec `json:"sidecars,omitempty"`
 }
@@ -63,6 +64,7 @@ type BuilderSpec struct {
 	Readme     string                               `json:"readme,omitempty"`
 	Services   map[string]AcornBuilderSpec          `json:"services,omitempty"`
 	Containers map[string]ContainerImageBuilderSpec `json:"containers,omitempty"`
+	Functions  map[string]ContainerImageBuilderSpec `json:"functions,omitempty"`
 	Jobs       map[string]ContainerImageBuilderSpec `json:"jobs,omitempty"`
 	Images     map[string]ImageBuilderSpec          `json:"images,omitempty"`
 	Acorns     map[string]AcornBuilderSpec          `json:"acorns,omitempty"`
