@@ -5,8 +5,9 @@ import (
 )
 
 type ContainerData struct {
-	Image    string               `json:"image,omitempty"`
-	Sidecars map[string]ImageData `json:"sidecars,omitempty"`
+	Image             string               `json:"image,omitempty"`
+	Sidecars          map[string]ImageData `json:"sidecars,omitempty"`
+	AcornfileFragment string               `json:"acornfileFragment,omitempty"`
 }
 
 type ImageData struct {
@@ -15,6 +16,7 @@ type ImageData struct {
 
 type ImagesData struct {
 	Containers map[string]ContainerData `json:"containers,omitempty"`
+	Functions  map[string]ContainerData `json:"functions,omitempty"`
 	Jobs       map[string]ContainerData `json:"jobs,omitempty"`
 	Images     map[string]ImageData     `json:"images,omitempty"`
 	Acorns     map[string]ImageData     `json:"acorns,omitempty"`
