@@ -18,11 +18,8 @@ type FieldType struct {
 }
 
 type Constraint struct {
-	Description string     `json:"description,omitempty"`
-	Op          string     `json:"op,omitempty"`
-	ID          string     `json:"id,omitempty"`
-	Right       string     `json:"right,omitempty"`
-	Type        *FieldType `json:"type,omitempty"`
+	Op    string `json:"op,omitempty"`
+	Right string `json:"right,omitempty"`
 }
 
 type Object struct {
