@@ -32,6 +32,50 @@ type routeTarget struct {
 	TargetServiceName string   `json:"targetServiceName,omitempty"`
 }
 
+func (in *UserContext) UnmarshalJSON(data []byte) error {
+	if !isString(data) {
+		var d int64
+		if err := json.Unmarshal(data, &d); err == nil {
+			in.UID = d
+			in.GID = d
+			return nil
+		}
+		type userContext UserContext
+		return json.Unmarshal(data, (*userContext)(in))
+	}
+
+	s, err := parseString(data)
+	if err != nil {
+		return err
+	}
+	parts := strings.Split(s, ":")
+
+	if len(parts) > 2 {
+		return fmt.Errorf("invalid user context has extra part: %s", s)
+	}
+
+	uid, err := strconv.ParseInt(parts[0], 10, 64)
+	if err != nil {
+		return fmt.Errorf("failed to parse uid %s in %s: %w", parts[0], s, err)
+	}
+	in.UID = uid
+	in.GID = uid
+
+	if len(parts) == 2 {
+		gid, err := strconv.ParseInt(parts[1], 10, 64)
+		if err != nil {
+			return fmt.Errorf("failed to parse gid %s in %s: %w", parts[1], s, err)
+		}
+		in.GID = gid
+	}
+
+	if in.UID < 0 || in.GID < 0 {
+		return fmt.Errorf("invalid user context uid or gid < 0: %s", s)
+	}
+
+	return nil
+}
+
 func (in *routeTarget) UnmarshalJSON(data []byte) error {
 	if !isString(data) {
 		type routeTargetType routeTarget
@@ -386,6 +430,11 @@ func checkForDuplicateNames(in *AppSpec) error {
 			return err
 		}
 	}
+	for name := range in.Functions {
+		if err := addName(names, name, "function"); err != nil {
+			return err
+		}
+	}
 	for name := range in.Jobs {
 		if err := addName(names, name, "job"); err != nil {
 			return err
@@ -411,11 +460,16 @@ func checkForDuplicateNames(in *AppSpec) error {
 			return err
 		}
 	}
+	for name := range in.Assistants {
+		if err := addName(names, name, "assistant"); err != nil {
+			return err
+		}
+	}
 
 	return nil
 }
 
-func addImpliedResources(in *AppSpec) error {
+func AddImpliedResources(in *AppSpec) error {
 	if in.Volumes == nil {
 		in.Volumes = map[string]VolumeRequest{}
 	}
@@ -460,6 +514,19 @@ func addImpliedResources(in *AppSpec) error {
 		}
 	}
 
+	for functionName, c := range in.Functions {
+		impliedSecretsForContainer(in, c)
+		if err := impliedVolumesForContainer(in, functionName, "", c); err != nil {
+			return err
+		}
+		for sidecarName, s := range c.Sidecars {
+			impliedSecretsForContainer(in, s)
+			if err := impliedVolumesForContainer(in, functionName, sidecarName, s); err != nil {
+				return err
+			}
+		}
+	}
+
 	for containerName, j := range in.Jobs {
 		impliedSecretsForContainer(in, j)
 		if err := impliedVolumesForContainer(in, containerName, "", j); err != nil {
@@ -482,7 +549,7 @@ func (in *AppSpec) UnmarshalJSON(data []byte) error {
 		return err
 	}
 
-	if err := addImpliedResources(in); err != nil {
+	if err := AddImpliedResources(in); err != nil {
 		return err
 	}
 
@@ -637,13 +704,13 @@ func (c containerAliases) SetContainer(dst Container) Container {
 		dst.Dirs = c.Directories
 	}
 	if len(c.DependsOn) > 0 {
-		dst.Dependencies = c.DependsOn
+		dst.Dependencies = append(dst.Dependencies, c.DependsOn...)
 	}
 	if len(c.DependsOnUnderscore) > 0 {
-		dst.Dependencies = c.DependsOnUnderscore
+		dst.Dependencies = append(dst.Dependencies, c.DependsOnUnderscore...)
 	}
 	if len(c.Consumes) > 0 {
-		dst.Dependencies = c.Consumes
+		dst.Dependencies = append(dst.Dependencies, c.Consumes...)
 	}
 	if c.Memory != nil {
 		dst.Memory = c.Memory
@@ -692,6 +759,22 @@ func (in *Acorn) UnmarshalJSON(data []byte) error {
 	return nil
 }
 
+func (in *Prompts) UnmarshalJSON(data []byte) error {
+	*in = Prompts{}
+
+	if isString(data) {
+		s, err := parseString(data)
+		if err != nil {
+			return err
+		}
+		*in = append(*in, s)
+		return nil
+	}
+
+	type prompts Prompts
+	return json.Unmarshal(data, (*prompts)(in))
+}
+
 func (in *Container) UnmarshalJSON(data []byte) error {
 	var c Container
 	type container Container
@@ -930,7 +1013,7 @@ func (in *VolumeMount) UnmarshalJSON(data []byte) error {
 	} else if strings.HasPrefix(s, "./") {
 		in.ContextDir = s
 	} else {
-		in.Volume, in.SubPath, err = parseVolumeReference(s)
+		in.Volume, in.SubPath, in.Preload, err = parseVolumeReference(s)
 		if err != nil {
 			return err
 		}
@@ -1073,7 +1156,7 @@ func (in *EnvVars) UnmarshalJSON(data []byte) error {
 			if ok {
 				v.Secret = sec.SecretReference
 			} else {
-				v.Name = k
+				v.Name = strings.ReplaceAll(k, ".", "\\.") // escape dots so they don't interfere with name separator '.' during interpolation
 			}
 			*in = append(*in, (EnvVar)(v))
 		}
@@ -1313,7 +1396,7 @@ func parseEnvVar(key, value string) (result EnvVar, _ error) {
 		return result, nil
 	}
 
-	result.Name = key
+	result.Name = strings.ReplaceAll(key, ".", "\\.") // escape dots so they don't interfere with name separator '.' during interpolation
 
 	sec, ok, err = parseSecretReference(value)
 	if err != nil {
@@ -1352,7 +1435,7 @@ func parseVolumeDefinition(anonName, s string) (VolumeBinding, error) {
 	if u.Scheme == "ephemeral" {
 		result.Class = u.Scheme
 		if result.Volume == "" {
-			result.Volume = anonName
+			result.Volume = strings.ReplaceAll(anonName, "/", "-") // While a path-style name is OK in runtime, it breaks as resource name in manager
 		}
 	}
 
@@ -1367,14 +1450,19 @@ func parseVolumeDefinition(anonName, s string) (VolumeBinding, error) {
 	return result, nil
 }
 
-func parseVolumeReference(s string) (string, string, error) {
+// parseVolumeReference parses a volume reference string into its components, including query parameters
+// @return string - volume reference (unmodified)
+// @return string - subpath that should be mounted (query param)
+// @return bool 	- preload: if the volume should be pre-populated with data from the container image (query param)
+// @return error 	- parse error
+func parseVolumeReference(s string) (string, string, bool, error) {
 	if !strings.HasPrefix(s, "volume://") && !strings.HasPrefix(s, "ephemeral://") {
-		return s, "", nil
+		return s, "", false, nil
 	}
 
 	u, err := url.Parse(s)
 	if err != nil {
-		return "", "", fmt.Errorf("parsing volume reference %s: %w", s, err)
+		return "", "", false, fmt.Errorf("parsing volume reference %s: %w", s, err)
 	}
 
 	subPath := u.Query().Get("subPath")
@@ -1385,7 +1473,16 @@ func parseVolumeReference(s string) (string, string, error) {
 		subPath = u.Query().Get("sub-path")
 	}
 
-	return s, subPath, nil
+	preload := false
+	preloadStr := u.Query().Get("preload")
+	if preloadStr != "" {
+		preload, err = strconv.ParseBool(preloadStr)
+		if err != nil {
+			return "", "", false, fmt.Errorf("malformed ?preload value %q: %v", preloadStr, err)
+		}
+	}
+
+	return s, subPath, preload, nil
 }
 
 func MustParseResourceQuantity(s Quantity) *resource.Quantity {
@@ -1421,15 +1518,18 @@ func ParseQuantity(s string) (Quantity, error) {
 
 func ParseNameValues(fillEnv bool, s ...string) (result []NameValue) {
 	for _, s := range s {
+		s = strings.TrimSpace(s)
 		k, v, _ := strings.Cut(s, "=")
 		if v == "" && fillEnv {
 			parts := strings.Split(k, ".")
 			v = os.Getenv(parts[len(parts)-1])
 		}
-		result = append(result, NameValue{
-			Name:  k,
-			Value: v,
-		})
+		if k != "" {
+			result = append(result, NameValue{
+				Name:  k,
+				Value: v,
+			})
+		}
 	}
 	return result
 }
