@@ -6,6 +6,7 @@ import (
 	"os"
 	"path/filepath"
 	"strconv"
+	"strings"
 	"testing"
 
 	"cuelang.org/go/cue/errors"
@@ -42,28 +43,6 @@ icon: "./icon"
 	assert.Equal(t, "./icon", appSpec.Icon)
 }
 
-func TestOldSyntax(t *testing.T) {
-	_, err := NewAppDefinition([]byte(`args: name: string | *"hi"
-containers: foo: image: args.name
-`))
-	require.Error(t, err)
-
-	appImage, err := NewAppDefinition([]byte(`//acorn:amlv0
-args: name: string | *"hi"
-containers: foo: image: args.name
-`))
-	if err != nil {
-		t.Fatal(err)
-	}
-
-	appSpec, err := appImage.AppSpec()
-	if err != nil {
-		t.Fatal(err)
-	}
-
-	assert.Equal(t, "hi", appSpec.Containers["foo"].Image)
-}
-
 func TestProfilesImplicitArgs(t *testing.T) {
 	appImage, err := NewAppDefinition([]byte(`profiles: a: {}, profiles: d: {}
 std.debug("debugs", args.profiles)
@@ -314,7 +293,6 @@ acorns: {
 
 	buildSpec, err := appImage.BuilderSpec()
 	if err != nil {
-		errors.Print(os.Stderr, err, nil)
 		t.Fatal(err)
 	}
 
@@ -1112,87 +1090,65 @@ images: {
 		t.Fatal(err)
 	}
 
-	assert.Equal(t, &v1.BuilderSpec{
+	autogold.Expect(&v1.BuilderSpec{
 		Containers: map[string]v1.ContainerImageBuilderSpec{
-			"image": {
-				Image: "image-image",
-				Sidecars: map[string]v1.ContainerImageBuilderSpec{
-					"side": {
-						Image: "image-image-side",
-					},
-				},
-			},
 			"build": {
 				Build: &v1.Build{
 					Context:    ".",
 					Dockerfile: "Dockerfile",
+					WatchFiles: []string{},
 				},
-				Sidecars: map[string]v1.ContainerImageBuilderSpec{
-					"side": {
-						Build: &v1.Build{
-							Context:    ".",
-							Dockerfile: "Dockerfile",
-						},
-					},
-				},
+				Sidecars: map[string]v1.ContainerImageBuilderSpec{"side": {Build: &v1.Build{
+					Context:    ".",
+					Dockerfile: "Dockerfile",
+					WatchFiles: []string{},
+				}}},
 			},
 			"buildcontext": {
 				Build: &v1.Build{
-					Context:    ".",
-					Dockerfile: "Dockerfile",
-					ContextDirs: map[string]string{
-						"/var/tmp": "./foo/bar",
-					},
-				},
-				Sidecars: map[string]v1.ContainerImageBuilderSpec{
-					"side": {
-						Build: &v1.Build{
-							Context:    ".",
-							Dockerfile: "Dockerfile",
-							ContextDirs: map[string]string{
-								"/var/tmp": "./foo/bar",
-							},
-						},
-					},
+					Context:     ".",
+					Dockerfile:  "Dockerfile",
+					ContextDirs: map[string]string{"/var/tmp": "./foo/bar"},
+					WatchFiles:  []string{},
 				},
+				Sidecars: map[string]v1.ContainerImageBuilderSpec{"side": {Build: &v1.Build{
+					Context:     ".",
+					Dockerfile:  "Dockerfile",
+					ContextDirs: map[string]string{"/var/tmp": "./foo/bar"},
+					WatchFiles:  []string{},
+				}}},
+			},
+			"image": {
+				Image:    "image-image",
+				Sidecars: map[string]v1.ContainerImageBuilderSpec{"side": {Image: "image-image-side"}},
 			},
 			"imagecontext": {
 				Image: "imagecontext-image",
 				Build: &v1.Build{
-					BaseImage:  "imagecontext-image",
-					Context:    ".",
-					Dockerfile: "Dockerfile",
-					ContextDirs: map[string]string{
-						"/var/tmp": "./foo/bar",
-					},
+					Context:     ".",
+					Dockerfile:  "Dockerfile",
+					BaseImage:   "imagecontext-image",
+					ContextDirs: map[string]string{"/var/tmp": "./foo/bar"},
 				},
-				Sidecars: map[string]v1.ContainerImageBuilderSpec{
-					"side": {
-						Image: "imagecontext-image-side",
-						Build: &v1.Build{
-							BaseImage:  "imagecontext-image-side",
-							Context:    ".",
-							Dockerfile: "Dockerfile",
-							ContextDirs: map[string]string{
-								"/var/tmp": "./foo/bar",
-							},
-						},
+				Sidecars: map[string]v1.ContainerImageBuilderSpec{"side": {
+					Image: "imagecontext-image-side",
+					Build: &v1.Build{
+						Context:     ".",
+						Dockerfile:  "Dockerfile",
+						BaseImage:   "imagecontext-image-side",
+						ContextDirs: map[string]string{"/var/tmp": "./foo/bar"},
 					},
-				},
+				}},
 			},
 		},
 		Images: map[string]v1.ImageBuilderSpec{
-			"ibuild": {
-				AcornBuild: &v1.AcornBuild{
-					Context:   ".",
-					Acornfile: "Acornfile",
-				},
-			},
-			"iimage": {
-				Image: "images-image-image",
-			},
+			"ibuild": {AcornBuild: &v1.AcornBuild{
+				Context:   ".",
+				Acornfile: "Acornfile",
+			}},
+			"iimage": {Image: "images-image-image"},
 		},
-	}, buildSpec)
+	}).Equal(t, buildSpec)
 
 	app := appImage.WithImageData(v1.ImagesData{
 		Containers: map[string]v1.ContainerData{
@@ -1380,8 +1336,8 @@ volumes: {
 	assert.Equal(t, v1.AccessModes{"readWriteMany", "readWriteOnce"}, appSpec.Volumes["uri"].AccessModes)
 	assert.Equal(t, v1.Quantity(""), appSpec.Volumes["uri-sub"].Size)
 	assert.Nil(t, appSpec.Volumes["uri-sub"].AccessModes)
-	assert.Equal(t, "ephemeral", appSpec.Volumes["s/left/var/anon-ephemeral-vol"].Class)
-	assert.Equal(t, "ephemeral", appSpec.Volumes["s/left/var/anon-ephemeral2-vol"].Class)
+	assert.Equal(t, "ephemeral", appSpec.Volumes["s-left-var-anon-ephemeral-vol"].Class)
+	assert.Equal(t, "ephemeral", appSpec.Volumes["s-left-var-anon-ephemeral2-vol"].Class)
 	assert.Equal(t, "ephemeral", appSpec.Volumes["eph"].Class)
 	assert.Len(t, typed.SortedKeys(appSpec.Volumes), 11)
 
@@ -1396,9 +1352,9 @@ volumes: {
 	assert.Equal(t, "", sidecar.Dirs["/var/uri-vol"].SubPath)
 	assert.Equal(t, "uri-sub", sidecar.Dirs["/var/uri-sub-vol"].Volume)
 	assert.Equal(t, "sub", sidecar.Dirs["/var/uri-sub-vol"].SubPath)
-	assert.Equal(t, filepath.Join("s", "left", "var", "anon-ephemeral-vol"), sidecar.Dirs["/var/anon-ephemeral-vol"].Volume)
+	assert.Equal(t, strings.ReplaceAll(filepath.Join("s", "left", "var", "anon-ephemeral-vol"), "/", "-"), sidecar.Dirs["/var/anon-ephemeral-vol"].Volume)
 	assert.Equal(t, "", sidecar.Dirs["/var/anon-ephemeral-vol"].SubPath)
-	assert.Equal(t, filepath.Join("s", "left", "var", "anon-ephemeral2-vol"), sidecar.Dirs["/var/anon-ephemeral2-vol"].Volume)
+	assert.Equal(t, strings.ReplaceAll(filepath.Join("s", "left", "var", "anon-ephemeral2-vol"), "/", "-"), sidecar.Dirs["/var/anon-ephemeral2-vol"].Volume)
 	assert.Equal(t, "", sidecar.Dirs["/var/anon-ephemeral2-vol"].SubPath)
 	assert.Equal(t, "eph", sidecar.Dirs["/var/named-ephemeral-vol"].Volume)
 	assert.Equal(t, "", sidecar.Dirs["/var/named-ephemeral-vol"].SubPath)
@@ -1589,7 +1545,7 @@ for i in std.range(1,args.scale+1) {
 	}
 
 	app = app.WithImageData(*image)
-	devApp := app.WithArgs(map[string]any{"scale": 2}, nil)
+	devApp := app.WithArgs(map[string]any{"scale": 4}, nil)
 
 	appSpec, err := devApp.AppSpec()
 	if err != nil {
@@ -2583,12 +2539,12 @@ localData: {
 
 func TestStdMissing(t *testing.T) {
 	data := `
-foo : std.toyaml({})
+localData: foo : std.toyaml({})
 `
 
 	_, err := NewAppDefinition([]byte(data))
 	require.Error(t, err)
-	assert.Contains(t, err.Error(), "key not found \"toyaml\": Acornfile:2:11")
+	assert.Contains(t, err.Error(), "key not found \"toyaml\": Acornfile:2:22")
 }
 
 func TestArgsTopCondition(t *testing.T) {
@@ -3058,3 +3014,79 @@ func TestNestedScopedLabels(t *testing.T) {
 	}}`))
 	assert.Error(t, err)
 }
+
+func TestFunction(t *testing.T) {
+	appImage, err := NewAppDefinition([]byte(`functions: foo: {
+		src: "somewhere"
+	}`))
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	appSpec, err := appImage.AppSpec()
+	if err != nil {
+		errors.Print(os.Stderr, err, nil)
+		t.Fatal(err)
+	}
+
+	autogold.Expect(v1.Container{
+		Src: "somewhere",
+	}).Equal(t, appSpec.Functions["foo"])
+
+	_, err = NewAppDefinition([]byte(`functions: foo: {
+		src: "somewhere"
+	}
+	containers: foo: {
+			image: "foo:latest"
+	}`))
+	autogold.Expect("duplicate name [foo] used by [container] and [function]").Equal(t, err.Error())
+}
+
+func TestUserContext(t *testing.T) {
+	appImage, err := NewAppDefinition([]byte(`containers: foo: {
+		image: "foo:latest"
+		user: "1000:2000"
+	}`))
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	appSpec, err := appImage.AppSpec()
+	if err != nil {
+		errors.Print(os.Stderr, err, nil)
+		t.Fatal(err)
+	}
+
+	require.Equal(t, &v1.UserContext{UID: 1000, GID: 2000}, appSpec.Containers["foo"].UserContext)
+
+	// GID default to UID
+	nAppImage, err := NewAppDefinition([]byte(`containers: foo: {
+		image: "foo:latest"
+		user: "1000"
+	}`))
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	nAppSpec, err := nAppImage.AppSpec()
+	if err != nil {
+		errors.Print(os.Stderr, err, nil)
+		t.Fatal(err)
+	}
+
+	require.Equal(t, &v1.UserContext{UID: 1000, GID: 1000}, nAppSpec.Containers["foo"].UserContext)
+
+	// Expect error because of non-integer values
+	_, err = NewAppDefinition([]byte(`containers: foo: {
+		image: "foo:latest"
+		user: "me:you"
+	}`))
+	require.Error(t, err)
+
+	// Expect error because of third entry
+	_, err = NewAppDefinition([]byte(`containers: foo: {
+		image: "foo:latest"
+		user: "1000:1000:1000"
+	}`))
+	require.Error(t, err)
+}
