@@ -5,6 +5,7 @@ import (
 
 	cli "github.com/acorn-io/runtime/pkg/cli/builder"
 	"github.com/acorn-io/runtime/pkg/project"
+	"github.com/sirupsen/logrus"
 	"github.com/spf13/cobra"
 )
 
@@ -31,17 +32,31 @@ func (a *ProjectUse) Run(cmd *cobra.Command, args []string) error {
 		return err
 	}
 
+	target := args[0]
+
 	// They want to clear the default
-	if args[0] == "" {
+	if target == "" {
 		cfg.CurrentProject = ""
 		return cfg.Save()
 	}
 
-	err = project.Exists(cmd.Context(), a.client.Options(), args[0])
-	if err != nil {
-		return fmt.Errorf("failed to find project %s, use \"acorn projects\" to list valid project names: %w", args[0], err)
+	if target == "-" {
+		if cfg.LastProject == "" {
+			logrus.Debugf("no last project set")
+			return nil
+		}
+		target = cfg.LastProject
 	}
 
-	cfg.CurrentProject = args[0]
+	err = project.Exists(cmd.Context(), a.client.Options(), target)
+	if err != nil {
+		return fmt.Errorf("failed to find project %s, use \"acorn projects\" to list valid project names: %w", target, err)
+	}
+
+	if cfg.CurrentProject != target {
+		// make sure we don't update lastProject if we're not actually switching
+		cfg.LastProject = cfg.CurrentProject
+	}
+	cfg.CurrentProject = target
 	return cfg.Save()
 }
