@@ -11,8 +11,9 @@ import (
 
 func (c *DefaultClient) ImageVerify(ctx context.Context, image string, opts *ImageVerifyOptions) (*apiv1.ImageSignature, error) {
 	sigInput := &apiv1.ImageSignature{
-		PublicKey: opts.PublicKey,
-		Auth:      opts.Auth,
+		PublicKey:    opts.PublicKey,
+		Auth:         opts.Auth,
+		NoVerifyName: opts.NoVerifyName,
 	}
 
 	if opts.PublicKey == "" {
@@ -23,18 +24,11 @@ func (c *DefaultClient) ImageVerify(ctx context.Context, image string, opts *Ima
 		Match: opts.Annotations,
 	}
 
-	imageDetails, err := c.ImageDetails(ctx, image, &ImageDetailsOptions{Auth: opts.Auth})
-	if err != nil {
-		return nil, err
-	}
-
-	image = strings.ReplaceAll(imageDetails.AppImage.ID, "/", "+")
-
 	sigResult := &apiv1.ImageSignature{}
-	err = c.RESTClient.Post().
+	err := c.RESTClient.Post().
 		Namespace(c.Namespace).
 		Resource("images").
-		Name(image).
+		Name(strings.ReplaceAll(image, "/", "+")).
 		SubResource("verify").
 		Body(sigInput).Do(ctx).Into(sigResult)
 
