@@ -12,6 +12,7 @@ import (
 	"strconv"
 	"strings"
 
+	wname "github.com/acorn-io/baaah/pkg/name"
 	"github.com/acorn-io/baaah/pkg/router"
 	"github.com/acorn-io/baaah/pkg/typed"
 	v1 "github.com/acorn-io/runtime/pkg/apis/internal.acorn.io/v1"
@@ -28,9 +29,9 @@ import (
 	"github.com/acorn-io/runtime/pkg/services"
 	"github.com/acorn-io/runtime/pkg/system"
 	"github.com/acorn-io/runtime/pkg/volume"
+	"github.com/acorn-io/schemer/data/convert"
 	"github.com/acorn-io/z"
 	"github.com/google/go-containerregistry/pkg/name"
-	"github.com/rancher/wrangler/pkg/data/convert"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	apierror "k8s.io/apimachinery/pkg/api/errors"
@@ -97,7 +98,12 @@ func DeploySpec(req router.Request, resp router.Response) (err error) {
 	} else if len(objs) > 0 {
 		result = append(result, objs...)
 	}
-	if objs, err := toRouters(appInstance); err != nil {
+	if objs, err := ToFunctions(req, appInstance, tag, pullSecrets, interpolator); err != nil {
+		return err
+	} else {
+		result = append(result, objs...)
+	}
+	if objs, err := toRouters(req.Ctx, req.Client, appInstance); err != nil {
 		return err
 	} else {
 		result = append(result, objs...)
@@ -159,8 +165,9 @@ func toEnv(envs []v1.EnvVar, appEnvs []v1.NameValue, interpolator *secrets.Inter
 			if appEnvNames.Has(env.Name) {
 				continue
 			}
-			interpolated, ok := interpolator.ToEnv(env.Name, env.Value)
-			if ok {
+			interpolated, noDotInKey := interpolator.ToEnv(env.Name, env.Value)
+			if noDotInKey {
+				interpolated.Name = strings.ReplaceAll(interpolated.Name, "\\.", ".") // restore dots that were escaped during unmarshalling
 				result = append(result, interpolated)
 			}
 		} else {
@@ -170,14 +177,15 @@ func toEnv(envs []v1.EnvVar, appEnvs []v1.NameValue, interpolator *secrets.Inter
 			if appEnvNames.Has(env.Name) {
 				continue
 			}
-			if strings.Contains(env.Secret.Name, ".") {
-				interpolated, ok := interpolator.ToEnv(env.Name, fmt.Sprintf("@{secrets.%s.%s}", env.Secret.Name, env.Secret.Key))
-				if ok {
+			if secrets.HasUnescapedDot(env.Secret.Name) {
+				interpolated, noDotInKey := interpolator.ToEnv(env.Name, fmt.Sprintf("@{secrets.%s.%s}", env.Secret.Name, env.Secret.Key))
+				if noDotInKey {
+					interpolated.Name = strings.ReplaceAll(interpolated.Name, "\\.", ".") // restore dots that were escaped during unmarshalling
 					result = append(result, interpolated)
 				}
 			} else {
 				result = append(result, corev1.EnvVar{
-					Name: env.Name,
+					Name: strings.ReplaceAll(env.Name, "\\.", "."), // restore dots that were escaped during unmarshalling
 					ValueFrom: &corev1.EnvVarSource{
 						SecretKeyRef: &corev1.SecretKeySelector{
 							LocalObjectReference: corev1.LocalObjectReference{
@@ -191,8 +199,9 @@ func toEnv(envs []v1.EnvVar, appEnvs []v1.NameValue, interpolator *secrets.Inter
 		}
 	}
 	for _, appEnv := range appEnvs {
-		interpolated, ok := interpolator.ToEnv(appEnv.Name, appEnv.Value)
-		if ok {
+		interpolated, noDotInKey := interpolator.ToEnv(appEnv.Name, appEnv.Value)
+		if noDotInKey {
+			interpolated.Name = strings.ReplaceAll(interpolated.Name, "\\.", ".") // restore dots that were escaped during unmarshalling
 			result = append(result, interpolated)
 		}
 	}
@@ -213,7 +222,7 @@ func hasContextDir(container v1.Container) bool {
 	return false
 }
 
-func toContainers(app *v1.AppInstance, tag name.Reference, name string, container v1.Container, interpolator *secrets.Interpolator, addWait bool) ([]corev1.Container, []corev1.Container) {
+func toContainers(app *v1.AppInstance, tag name.Reference, name string, container v1.Container, interpolator *secrets.Interpolator, addWait, addBusybox bool) ([]corev1.Container, []corev1.Container) {
 	var (
 		containers     []corev1.Container
 		initContainers []corev1.Container
@@ -234,7 +243,49 @@ func toContainers(app *v1.AppInstance, tag name.Reference, name string, containe
 		})
 	}
 
+	if addBusybox {
+		// Drop the static busybox binary into a shared volume so that we can use it in initContainers.
+		initContainers = append(initContainers, corev1.Container{
+			Name:    wname.SafeConcatName("acorn-helper-busybox", string(app.UID)),
+			Image:   system.DefaultImage(),
+			Command: []string{"acorn-busybox-init"},
+			VolumeMounts: []corev1.VolumeMount{
+				{
+					Name:      sanitizeVolumeName(AcornHelper),
+					MountPath: AcornHelperPath,
+				},
+			},
+		},
+		)
+	}
+
 	newContainer := toContainer(app, tag, name, container, interpolator, addWait && len(container.Ports) > 0)
+	for src, dir := range container.Dirs {
+		if dir.Preload {
+			// If a directory is marked for preload, then add an initContainer that copies the directory into the shared volume.
+			// Data will be copied to the data/ subdirectory and we'll drop a .preload-done file in the root to indicate that
+			// the copy has been completed (and should not be repeated).
+			initContainers = append(initContainers, corev1.Container{
+				Name:            wname.SafeConcatName("acorn-preload-dir", sanitizeVolumeName(src), string(app.UID)),
+				Image:           newContainer.Image,
+				Command:         []string{AcornHelperBusyboxPath, "sh", "-c"},
+				ImagePullPolicy: corev1.PullIfNotPresent,
+				// cp -aT == copy recursively, following symlinks and preserving file attributes, only copy the contents of the source directory
+				Args: []string{fmt.Sprintf("if [ ! -f /dest/.preload-done ]; then mkdir -p /dest/data && cp -aT %s /dest/data && date > /dest/.preload-done; fi", src)},
+				VolumeMounts: []corev1.VolumeMount{
+					{
+						Name:      sanitizeVolumeName(dir.Volume),
+						MountPath: "/dest",
+						SubPath:   dir.SubPath,
+					},
+					{
+						Name:      sanitizeVolumeName(AcornHelper),
+						MountPath: AcornHelperPath,
+					},
+				},
+			})
+		}
+	}
 	containers = append(containers, newContainer)
 	for _, entry := range typed.Sorted(container.Sidecars) {
 		newContainer = toContainer(app, tag, entry.Key, entry.Value, interpolator, addWait && len(entry.Value.Ports) > 0)
@@ -293,11 +344,18 @@ func toMounts(app *v1.AppInstance, container v1.Container, interpolation *secret
 				helperMounted = true
 			}
 		} else if mount.Secret.Name == "" {
-			result = append(result, corev1.VolumeMount{
+			vm := corev1.VolumeMount{
 				Name:      sanitizeVolumeName(mount.Volume),
 				MountPath: path.Join("/", mountPath),
 				SubPath:   mount.SubPath,
-			})
+			}
+			if mount.Preload {
+				// Preloaded contents land in the data/ subdirectory, since we have to drop the .preload-done file
+				// in the root of the volume to indicate that the copy has been completed
+				// and that may cause issues with applications that dislike unknown files in their path.
+				vm.SubPath = path.Join(vm.SubPath, "data")
+			}
+			result = append(result, vm)
 		} else {
 			result = append(result, corev1.VolumeMount{
 				Name:      secretPodVolName(mount.Secret.Name),
@@ -454,6 +512,13 @@ func toContainer(app *v1.AppInstance, tag name.Reference, containerName string,
 		Resources:      app.Status.Scheduling[containerName].Requirements,
 	}
 
+	if container.UserContext != nil {
+		containerObject.SecurityContext = &corev1.SecurityContext{
+			RunAsUser:  z.Pointer(container.UserContext.UID),
+			RunAsGroup: z.Pointer(container.UserContext.GID),
+		}
+	}
+
 	if addWait {
 		// If a container exposes a port, then add a pre-stop lifecycle hook that sleeps for 5 seconds. This should allow the
 		// endpoints controller to remove the pods IP on termination and stop sending traffic to the container.
@@ -470,6 +535,10 @@ func toContainer(app *v1.AppInstance, tag name.Reference, containerName string,
 	return containerObject
 }
 
+func functionAnnotations(appInstance *v1.AppInstance, container v1.Container, name string) map[string]string {
+	return labels.GatherScoped(name, v1.LabelTypeFunction, appInstance.Status.AppSpec.Annotations, container.Annotations, appInstance.Spec.Annotations)
+}
+
 func containerAnnotations(appInstance *v1.AppInstance, container v1.Container, name string) map[string]string {
 	return labels.GatherScoped(name, v1.LabelTypeContainer, appInstance.Status.AppSpec.Annotations, container.Annotations, appInstance.Spec.Annotations)
 }
@@ -504,6 +573,12 @@ func addInterpolationLabels(result map[string]string, interpolator *secrets.Inte
 	return result, nil
 }
 
+func functionLabels(appInstance *v1.AppInstance, container v1.Container, name string, interpolator *secrets.Interpolator, kv ...string) (map[string]string, error) {
+	labelMap := labels.GatherScoped(name, v1.LabelTypeFunction, appInstance.Status.AppSpec.Labels, container.Labels, appInstance.Spec.Labels)
+	result := mergeFuncLabels(labelMap, appInstance, name, append([]string{labels.AcornAppPublicName, publicname.Get(appInstance)}, kv...)...)
+	return addInterpolationLabels(result, interpolator)
+}
+
 func containerLabels(appInstance *v1.AppInstance, container v1.Container, name string, interpolator *secrets.Interpolator, kv ...string) (map[string]string, error) {
 	labelMap := labels.GatherScoped(name, v1.LabelTypeContainer, appInstance.Status.AppSpec.Labels, container.Labels, appInstance.Spec.Labels)
 	result := mergeConLabels(labelMap, appInstance, name, append([]string{labels.AcornAppPublicName, publicname.Get(appInstance)}, kv...)...)
@@ -519,6 +594,10 @@ func routerSelectorMatchLabels(appInstance *v1.AppInstance, name string, kv ...s
 	return mergeRouterLabels(make(map[string]string), appInstance, name, kv...)
 }
 
+func selectorMatchLabelsFunc(appInstance *v1.AppInstance, name string, kv ...string) map[string]string {
+	return mergeFuncLabels(make(map[string]string), appInstance, name, kv...)
+}
+
 func selectorMatchLabels(appInstance *v1.AppInstance, name string, kv ...string) map[string]string {
 	return mergeConLabels(make(map[string]string), appInstance, name, kv...)
 }
@@ -528,6 +607,11 @@ func mergeRouterLabels(labelMap map[string]string, appInstance *v1.AppInstance,
 	return labels.Merge(labelMap, labels.Managed(appInstance, kv...))
 }
 
+func mergeFuncLabels(labelMap map[string]string, appInstance *v1.AppInstance, name string, kv ...string) map[string]string {
+	kv = append([]string{labels.AcornFunctionName, name}, kv...)
+	return labels.Merge(labelMap, labels.Managed(appInstance, kv...))
+}
+
 func mergeConLabels(labelMap map[string]string, appInstance *v1.AppInstance, name string, kv ...string) map[string]string {
 	kv = append([]string{labels.AcornContainerName, name}, kv...)
 	return labels.Merge(labelMap, labels.Managed(appInstance, kv...))
@@ -540,12 +624,34 @@ func containerAnnotation(container v1.Container) string {
 	return string(json)
 }
 
+func resolvedOfferingsAnnotation(appInstance *v1.AppInstance, container v1.Container) (string, error) {
+	if resolved, exists := appInstance.Status.ResolvedOfferings.Containers[container.Name]; exists {
+		data, err := convert.EncodeToMap(resolved)
+		if err != nil {
+			return "", err
+		}
+
+		j, err := json.Marshal(data)
+		if err != nil {
+			return "", err
+		}
+
+		return string(j), nil
+	}
+	return "", nil
+}
+
 func podAnnotations(appInstance *v1.AppInstance, container v1.Container) map[string]string {
 	annotations := map[string]string{
 		labels.AcornContainerSpec: containerAnnotation(container),
 	}
 	addPrometheusAnnotations(annotations, container)
 
+	offerings, err := resolvedOfferingsAnnotation(appInstance, container)
+	if err == nil && offerings != "" {
+		annotations[labels.AcornContainerResolvedOfferings] = offerings
+	}
+
 	images := map[string]string{}
 	addImageAnnotations(images, appInstance, container)
 
@@ -661,22 +767,110 @@ func getSecretAnnotations(req router.Request, appInstance *v1.AppInstance, conta
 	return result, nil
 }
 
-func toDeployment(req router.Request, appInstance *v1.AppInstance, tag name.Reference, name string, container v1.Container, pullSecrets *PullSecrets, interpolator *secrets.Interpolator) (*appsv1.Deployment, error) {
-	var (
-		stateful = isStateful(appInstance, container)
-		addWait  = !stateful && len(acornSleepBinary) > 0 && z.Dereference(container.Scale) > 1 && !appInstance.Status.GetDevMode()
-	)
+func toFunctionDeployment(req router.Request, appInstance *v1.AppInstance, tag name.Reference, name string, container v1.Container, pullSecrets *PullSecrets, interpolator *secrets.Interpolator) (*appsv1.Deployment, error) {
+	interpolator = interpolator.ForFunction(name)
 
-	interpolator = interpolator.ForContainer(name)
-
-	containers, initContainers := toContainers(appInstance, tag, name, container, interpolator, addWait)
+	container.Ports = ports.FunctionPortDefs(false)
+	containers, initContainers := toContainers(appInstance, tag, name, container, interpolator, false, false)
 
 	secretAnnotations, err := getSecretAnnotations(req, appInstance, container, interpolator)
 	if err != nil {
 		return nil, err
 	}
 
-	volumes, err := toVolumes(appInstance, container, interpolator, addWait)
+	volumes, err := toVolumes(appInstance, container, interpolator, false, false)
+	if err != nil {
+		return nil, err
+	}
+
+	podLabels, err := functionLabels(appInstance, container, name, interpolator)
+	if err != nil {
+		return nil, err
+	}
+	deploymentLabels, err := functionLabels(appInstance, container, name, interpolator)
+	if err != nil {
+		return nil, err
+	}
+	matchLabels := selectorMatchLabelsFunc(appInstance, name)
+
+	deploymentAnnotations := functionAnnotations(appInstance, container, name)
+
+	dep := &appsv1.Deployment{
+		ObjectMeta: metav1.ObjectMeta{
+			Name:        name,
+			Namespace:   appInstance.Status.Namespace,
+			Labels:      deploymentLabels,
+			Annotations: typed.Concat(deploymentAnnotations, getDependencyAnnotations(appInstance, name, container.Dependencies), secretAnnotations, map[string]string{labels.AcornConfigHashAnnotation: appInstance.Status.AppStatus.Functions[name].ConfigHash}),
+		},
+		Spec: appsv1.DeploymentSpec{
+			Replicas: container.Scale,
+			Selector: &metav1.LabelSelector{
+				MatchLabels: matchLabels,
+			},
+			Template: corev1.PodTemplateSpec{
+				ObjectMeta: metav1.ObjectMeta{
+					Labels:      podLabels,
+					Annotations: typed.Concat(deploymentAnnotations, podAnnotations(appInstance, container), secretAnnotations),
+				},
+				Spec: corev1.PodSpec{
+					Affinity:           appInstance.Status.Scheduling[name].Affinity,
+					Tolerations:        appInstance.Status.Scheduling[name].Tolerations,
+					PriorityClassName:  appInstance.Status.Scheduling[name].PriorityClassName,
+					RuntimeClassName:   stringOrNilPtr(appInstance.Status.Scheduling[name].RuntimeClassName),
+					ImagePullSecrets:   pullSecrets.ForContainer(name, append(containers, initContainers...)),
+					EnableServiceLinks: new(bool),
+					Containers:         containers,
+					InitContainers:     initContainers,
+					Volumes:            volumes,
+					ServiceAccountName: name,
+				},
+			},
+		},
+	}
+
+	if appInstance.Spec.Stop != nil && *appInstance.Spec.Stop {
+		dep.Spec.Replicas = new(int32)
+	} else {
+		interpolator.AddMissingAnnotations(appInstance.GetStopped(), dep.Annotations)
+	}
+
+	// Set karpenter do-not-evict annotation if scale is nil or 1. This prevents karpenter from evicting the pod if deployment is not running with more than 1 replica.
+	if dep.Spec.Replicas == nil || *dep.Spec.Replicas == 1 {
+		cfg, err := config.Get(req.Ctx, req.Client)
+		if err != nil {
+			return nil, err
+		}
+		if z.Dereference(cfg.AutoConfigureKarpenterDontEvictAnnotations) {
+			dep.Spec.Template.Annotations["karpenter.sh/do-not-evict"] = "true"
+		}
+	}
+
+	return dep, nil
+}
+
+func toDeployment(req router.Request, appInstance *v1.AppInstance, tag name.Reference, name string, container v1.Container, pullSecrets *PullSecrets, interpolator *secrets.Interpolator) (*appsv1.Deployment, error) {
+	var (
+		stateful   = isStateful(appInstance, container)
+		addWait    = !stateful && len(acornSleepBinary) > 0 && z.Dereference(container.Scale) > 1 && !appInstance.Status.GetDevMode()
+		addBusybox = false
+	)
+
+	for _, v := range container.Dirs {
+		if v.Preload {
+			addBusybox = true
+		}
+	}
+
+	interpolator = interpolator.ForContainer(name)
+
+	containers, initContainers := toContainers(appInstance, tag, name, container, interpolator, addWait, addBusybox)
+
+	secretAnnotations, err := getSecretAnnotations(req, appInstance, container, interpolator)
+	if err != nil {
+		return nil, err
+	}
+
+	volumes, err := toVolumes(appInstance, container, interpolator, addWait, addBusybox)
 	if err != nil {
 		return nil, err
 	}
@@ -714,6 +908,7 @@ func toDeployment(req router.Request, appInstance *v1.AppInstance, tag name.Refe
 					Affinity:                      appInstance.Status.Scheduling[name].Affinity,
 					Tolerations:                   appInstance.Status.Scheduling[name].Tolerations,
 					PriorityClassName:             appInstance.Status.Scheduling[name].PriorityClassName,
+					RuntimeClassName:              stringOrNilPtr(appInstance.Status.Scheduling[name].RuntimeClassName),
 					TerminationGracePeriodSeconds: z.Pointer[int64](10),
 					ImagePullSecrets:              pullSecrets.ForContainer(name, append(containers, initContainers...)),
 					EnableServiceLinks:            new(bool),
@@ -742,12 +937,51 @@ func toDeployment(req router.Request, appInstance *v1.AppInstance, tag name.Refe
 
 	// Set karpenter do-not-evict annotation if scale is nil or 1. This prevents karpenter from evicting the pod if deployment is not running with more than 1 replica.
 	if dep.Spec.Replicas == nil || *dep.Spec.Replicas == 1 {
-		dep.Spec.Template.Annotations["karpenter.sh/do-not-evict"] = "true"
+		cfg, err := config.Get(req.Ctx, req.Client)
+		if err != nil {
+			return nil, err
+		}
+		if z.Dereference(cfg.AutoConfigureKarpenterDontEvictAnnotations) {
+			dep.Spec.Template.Annotations["karpenter.sh/do-not-evict"] = "true"
+		}
 	}
 
 	return dep, nil
 }
 
+func ToFunctions(req router.Request, appInstance *v1.AppInstance, tag name.Reference, pullSecrets *PullSecrets, secrets *secrets.Interpolator) (result []kclient.Object, _ error) {
+	for _, functionName := range typed.SortedKeys(appInstance.Status.AppSpec.Functions) {
+		functionDef := appInstance.Status.AppSpec.Functions[functionName]
+		if ports.IsLinked(appInstance, functionName) {
+			continue
+		}
+		functionDef, err := augmentContainerWithConsumerInfo(req.Ctx, req.Client, appInstance.Status.Namespace, functionDef)
+		if err != nil {
+			return nil, err
+		}
+		dep, err := toFunctionDeployment(req, appInstance, tag, functionName, functionDef, pullSecrets, secrets)
+		if err != nil {
+			return nil, err
+		}
+
+		perms := v1.FindPermission(functionName, appInstance.Status.Permissions)
+		sa, err := toServiceAccount(req, dep.GetName(), dep.GetLabels(), dep.GetAnnotations(), appInstance, perms)
+		if err != nil {
+			return nil, err
+		}
+		if perms.HasRules() {
+			perms, err := toPermissions(req.Ctx, req.Client, perms, dep.GetLabels(), dep.GetAnnotations(), appInstance)
+			if err != nil {
+				return nil, err
+			}
+			result = append(result, perms...)
+		}
+		result = append(result, sa, dep, pdb.ToPodDisruptionBudget(dep))
+	}
+
+	return result, nil
+}
+
 func ToDeployments(req router.Request, appInstance *v1.AppInstance, tag name.Reference, pullSecrets *PullSecrets, secrets *secrets.Interpolator) (result []kclient.Object, _ error) {
 	var configMapInitialized bool
 	for _, containerName := range typed.SortedKeys(appInstance.Status.AppSpec.Containers) {
@@ -803,3 +1037,10 @@ func ToDeployments(req router.Request, appInstance *v1.AppInstance, tag name.Ref
 
 	return result, nil
 }
+
+func stringOrNilPtr(s string) *string {
+	if s == "" {
+		return nil
+	}
+	return &s
+}
