@@ -13,6 +13,7 @@ import (
 	"github.com/acorn-io/runtime/pkg/secrets"
 	"github.com/google/go-containerregistry/pkg/name"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -98,11 +99,13 @@ func ToDeploymentsTest(t *testing.T, appInstance *v1.AppInstance, tag name.Refer
 func TestEntrypointCommand(t *testing.T) {
 	dep := ToDeploymentsTest(t, &v1.AppInstance{
 		Status: v1.AppInstanceStatus{
-			AppSpec: v1.AppSpec{
-				Containers: map[string]v1.Container{
-					"test": {
-						Entrypoint: []string{"hi", "bye"},
-						Command:    []string{"hi2", "bye2"},
+			EmbeddedAppStatus: v1.EmbeddedAppStatus{
+				AppSpec: v1.AppSpec{
+					Containers: map[string]v1.Container{
+						"test": {
+							Entrypoint: []string{"hi", "bye"},
+							Command:    []string{"hi2", "bye2"},
+						},
 					},
 				},
 			},
@@ -115,16 +118,29 @@ func TestEntrypointCommand(t *testing.T) {
 func TestEnvironment(t *testing.T) {
 	dep := ToDeploymentsTest(t, &v1.AppInstance{
 		Status: v1.AppInstanceStatus{
-			AppSpec: v1.AppSpec{
-				Containers: map[string]v1.Container{
-					"test": {
-						Environment: []v1.EnvVar{
-							{
-								Name:  "hi",
-								Value: "bye",
-							},
-							{
-								Name: "foo",
+			EmbeddedAppStatus: v1.EmbeddedAppStatus{
+				AppSpec: v1.AppSpec{
+					Containers: map[string]v1.Container{
+						"test": {
+							Environment: []v1.EnvVar{
+								{
+									Name:  "hi",
+									Value: "bye",
+								},
+								{
+									Name: "foo",
+								},
+								{
+									Name:  "foo\\.bar",
+									Value: "baz",
+								},
+								{
+									Name: "foo\\.bar\\.baz",
+									Secret: v1.SecretReference{
+										Name: "somesecret",
+										Key:  "somesecretkey",
+									},
+								},
 							},
 						},
 					},
@@ -141,16 +157,33 @@ func TestEnvironment(t *testing.T) {
 			Name:  "foo",
 			Value: "",
 		},
+		{
+			Name:  "foo.bar",
+			Value: "baz",
+		},
+		{
+			Name: "foo.bar.baz",
+			ValueFrom: &corev1.EnvVarSource{
+				SecretKeyRef: &corev1.SecretKeySelector{
+					Key: "somesecretkey",
+					LocalObjectReference: corev1.LocalObjectReference{
+						Name: "somesecret",
+					},
+				},
+			},
+		},
 	}, dep.Spec.Template.Spec.Containers[0].Env)
 }
 
 func TestWorkdir(t *testing.T) {
 	dep := ToDeploymentsTest(t, &v1.AppInstance{
 		Status: v1.AppInstanceStatus{
-			AppSpec: v1.AppSpec{
-				Containers: map[string]v1.Container{
-					"test": {
-						WorkingDir: "something",
+			EmbeddedAppStatus: v1.EmbeddedAppStatus{
+				AppSpec: v1.AppSpec{
+					Containers: map[string]v1.Container{
+						"test": {
+							WorkingDir: "something",
+						},
 					},
 				},
 			},
@@ -162,10 +195,12 @@ func TestWorkdir(t *testing.T) {
 func TestInteractive(t *testing.T) {
 	dep := ToDeploymentsTest(t, &v1.AppInstance{
 		Status: v1.AppInstanceStatus{
-			AppSpec: v1.AppSpec{
-				Containers: map[string]v1.Container{
-					"test": {
-						Interactive: true,
+			EmbeddedAppStatus: v1.EmbeddedAppStatus{
+				AppSpec: v1.AppSpec{
+					Containers: map[string]v1.Container{
+						"test": {
+							Interactive: true,
+						},
 					},
 				},
 			},
@@ -178,19 +213,21 @@ func TestInteractive(t *testing.T) {
 func TestSidecar(t *testing.T) {
 	dep := ToDeploymentsTest(t, &v1.AppInstance{
 		Status: v1.AppInstanceStatus{
-			AppSpec: v1.AppSpec{
-				Containers: map[string]v1.Container{
-					"test": {
-						Sidecars: map[string]v1.Container{
-							"left": {
-								Image: "sidecar",
-								Init:  true,
-							},
-							"right": {
-								Image: "sidecar2",
+			EmbeddedAppStatus: v1.EmbeddedAppStatus{
+				AppSpec: v1.AppSpec{
+					Containers: map[string]v1.Container{
+						"test": {
+							Sidecars: map[string]v1.Container{
+								"left": {
+									Image: "sidecar",
+									Init:  true,
+								},
+								"right": {
+									Image: "sidecar2",
+								},
 							},
+							WorkingDir: "something",
 						},
-						WorkingDir: "something",
 					},
 				},
 			},
@@ -203,26 +240,28 @@ func TestSidecar(t *testing.T) {
 func TestPorts(t *testing.T) {
 	dep := ToDeploymentsTest(t, &v1.AppInstance{
 		Status: v1.AppInstanceStatus{
-			AppSpec: v1.AppSpec{
-				Containers: map[string]v1.Container{
-					"test": {
-						Sidecars: map[string]v1.Container{
-							"left": {
-								Ports: []v1.PortDef{
-									{
-										Port:       90,
-										TargetPort: 91,
-										Protocol:   v1.ProtocolHTTP,
+			EmbeddedAppStatus: v1.EmbeddedAppStatus{
+				AppSpec: v1.AppSpec{
+					Containers: map[string]v1.Container{
+						"test": {
+							Sidecars: map[string]v1.Container{
+								"left": {
+									Ports: []v1.PortDef{
+										{
+											Port:       90,
+											TargetPort: 91,
+											Protocol:   v1.ProtocolHTTP,
+										},
 									},
 								},
 							},
-						},
-						WorkingDir: "something",
-						Ports: []v1.PortDef{
-							{
-								Port:       80,
-								TargetPort: 81,
-								Protocol:   v1.ProtocolHTTP,
+							WorkingDir: "something",
+							Ports: []v1.PortDef{
+								{
+									Port:       80,
+									TargetPort: 81,
+									Protocol:   v1.ProtocolHTTP,
+								},
 							},
 						},
 					},
@@ -243,40 +282,42 @@ func TestFiles(t *testing.T) {
 			UID:  "123",
 		},
 		Status: v1.AppInstanceStatus{
-			AppSpec: v1.AppSpec{
-				Containers: map[string]v1.Container{
-					"test2": {
-						Files: map[string]v1.File{
-							"/a2/b/c": {
-								Content: "ZA==",
+			EmbeddedAppStatus: v1.EmbeddedAppStatus{
+				AppSpec: v1.AppSpec{
+					Containers: map[string]v1.Container{
+						"test2": {
+							Files: map[string]v1.File{
+								"/a2/b/c": {
+									Content: "ZA==",
+								},
+								"/a1/b/c": {
+									Content: "ZQ==",
+								},
 							},
-							"/a1/b/c": {
-								Content: "ZQ==",
-							},
-						},
-						Sidecars: map[string]v1.Container{
-							"left": {
-								Files: map[string]v1.File{
-									"/a/b2//c":      {Content: "ZA=="},
-									"/a/b1/c2/../c": {Content: "ZQ=="},
+							Sidecars: map[string]v1.Container{
+								"left": {
+									Files: map[string]v1.File{
+										"/a/b2//c":      {Content: "ZA=="},
+										"/a/b1/c2/../c": {Content: "ZQ=="},
+									},
 								},
 							},
 						},
-					},
-					"test": {
-						Files: map[string]v1.File{
-							"/a2/b/c": {
-								Content: "ZA==",
+						"test": {
+							Files: map[string]v1.File{
+								"/a2/b/c": {
+									Content: "ZA==",
+								},
+								"/a1/b/c": {
+									Content: "ZQ==",
+								},
 							},
-							"/a1/b/c": {
-								Content: "ZQ==",
-							},
-						},
-						Sidecars: map[string]v1.Container{
-							"left": {
-								Files: map[string]v1.File{
-									"/a/b2//c":      {Content: "ZA=="},
-									"/a/b1/c2/../c": {Content: "ZQ=="},
+							Sidecars: map[string]v1.Container{
+								"left": {
+									Files: map[string]v1.File{
+										"/a/b2//c":      {Content: "ZA=="},
+										"/a/b1/c2/../c": {Content: "ZQ=="},
+									},
 								},
 							},
 						},
@@ -318,3 +359,40 @@ func TestFiles(t *testing.T) {
 	assert.Equal(t, []byte("d"), configMap.Data[toHash("ZA==")])
 	assert.Equal(t, []byte("e"), configMap.Data[toHash("ZQ==")])
 }
+
+func TestUserContext(t *testing.T) {
+	app := &v1.AppInstance{
+		Status: v1.AppInstanceStatus{
+			EmbeddedAppStatus: v1.EmbeddedAppStatus{
+				AppSpec: v1.AppSpec{
+					Containers: map[string]v1.Container{
+						"foo": {
+							Image: "foo:latest",
+							UserContext: &v1.UserContext{
+								UID: 1000,
+								GID: 2000,
+							},
+							Sidecars: map[string]v1.Container{
+								"bar": {
+									Image: "bar:latest",
+									UserContext: &v1.UserContext{
+										UID: 3000,
+										GID: 4000,
+									},
+								},
+							},
+						},
+					},
+				},
+			},
+		},
+	}
+
+	objs := ToDeploymentsTest(t, app, testTag, nil)
+	dep := objs[1].(*appsv1.Deployment)
+
+	require.Equal(t, int64(1000), *dep.Spec.Template.Spec.Containers[0].SecurityContext.RunAsUser)
+	require.Equal(t, int64(2000), *dep.Spec.Template.Spec.Containers[0].SecurityContext.RunAsGroup)
+	require.Equal(t, int64(3000), *dep.Spec.Template.Spec.Containers[1].SecurityContext.RunAsUser)
+	require.Equal(t, int64(4000), *dep.Spec.Template.Spec.Containers[1].SecurityContext.RunAsGroup)
+}
