@@ -5,6 +5,7 @@ import (
 	v1 "github.com/acorn-io/runtime/pkg/apis/internal.acorn.io/v1"
 	"github.com/acorn-io/runtime/pkg/appdefinition"
 	"github.com/acorn-io/runtime/pkg/condition"
+	"github.com/acorn-io/runtime/pkg/controller/permissions"
 )
 
 func ParseAppImage(req router.Request, resp router.Response) error {
@@ -22,11 +23,7 @@ func ParseAppImage(req router.Request, resp router.Response) error {
 		return nil
 	}
 
-	appDef, _, err = appDef.WithArgs(appInstance.Spec.DeployArgs, appInstance.Spec.GetProfiles(appInstance.Status.GetDevMode()))
-	if err != nil {
-		status.Error(err)
-		return nil
-	}
+	appDef = appDef.WithArgs(appInstance.Spec.DeployArgs.GetData(), appInstance.Spec.GetProfiles(appInstance.Status.GetDevMode()))
 
 	appSpec, err := appDef.AppSpec()
 	if err != nil {
@@ -34,6 +31,13 @@ func ParseAppImage(req router.Request, resp router.Response) error {
 		return nil
 	}
 
+	// Migration for AppScopedPermissions
+	if len(appInstance.Status.Staged.AppScopedPermissions) == 0 &&
+		appInstance.Status.Staged.PermissionsObservedGeneration == appInstance.Generation &&
+		len(appInstance.Status.Staged.ImagePermissionsDenied) == 0 {
+		appInstance.Status.Staged.AppScopedPermissions = permissions.GetAppScopedPermissions(appInstance, appSpec)
+	}
+
 	appInstance.Status.AppSpec = *appSpec
 	status.Success()
 	return nil
