@@ -39,6 +39,15 @@ func resetHandlerControlledFields(app *v1.AppInstance) {
 		app.Status.AppStatus.Containers[name] = status
 	}
 
+	for name, status := range app.Status.AppStatus.Functions {
+		// If the app is being updated, then set the containers to not ready so that the controller will run them again and the
+		// dependency status will be set correctly.
+		status.Ready = status.Ready && appUpToDate
+		status.ExpressionErrors = nil
+		status.Dependencies = nil
+		app.Status.AppStatus.Functions[name] = status
+	}
+
 	for name, status := range app.Status.AppStatus.Jobs {
 		status.ExpressionErrors = nil
 		status.Dependencies = nil
@@ -59,6 +68,7 @@ func resetHandlerControlledFields(app *v1.AppInstance) {
 
 	for name, status := range app.Status.AppStatus.Secrets {
 		status.Ready = status.Ready && appUpToDate
+		status.Missing = false
 		status.LookupErrors = nil
 		status.LookupTransitioning = nil
 		app.Status.AppStatus.Secrets[name] = status
@@ -74,10 +84,16 @@ func resetHandlerControlledFields(app *v1.AppInstance) {
 func PrepareStatus(req router.Request, _ router.Response) error {
 	app := req.Object.(*v1.AppInstance)
 
+	app.Status.AppStatus.LoginRequired = false
+
 	if app.Status.AppStatus.Containers == nil {
 		app.Status.AppStatus.Containers = map[string]v1.ContainerStatus{}
 	}
 
+	if app.Status.AppStatus.Functions == nil {
+		app.Status.AppStatus.Functions = map[string]v1.ContainerStatus{}
+	}
+
 	if app.Status.AppStatus.Jobs == nil {
 		app.Status.AppStatus.Jobs = map[string]v1.JobStatus{}
 	}
@@ -121,6 +137,7 @@ func SetStatus(req router.Request, _ router.Response) error {
 	status := app.Status.AppStatus
 
 	setCondition(app, v1.AppInstanceConditionContainers, status.Containers)
+	setCondition(app, v1.AppInstanceConditionFunctions, status.Functions)
 	setCondition(app, v1.AppInstanceConditionJobs, status.Jobs)
 	setCondition(app, v1.AppInstanceConditionVolumes, status.Volumes)
 	setCondition(app, v1.AppInstanceConditionServices, status.Services)
@@ -205,6 +222,7 @@ func setCondition[T commonStatusGetter](obj kclient.Object, conditionName string
 
 func setMessages(app *v1.AppInstance) {
 	setContainerMessages(app)
+	setFunctionMessages(app)
 	setJobMessages(app)
 	setVolumeMessages(app)
 	setServiceMessages(app)
@@ -224,6 +242,10 @@ func Get(ctx context.Context, c kclient.Client, app *v1.AppInstance) (v1.AppStat
 		return v1.AppStatus{}, err
 	}
 
+	if err := render.readFunctions(); err != nil {
+		return v1.AppStatus{}, err
+	}
+
 	if err := render.readJobs(); err != nil {
 		return v1.AppStatus{}, err
 	}
