@@ -30,9 +30,16 @@ func serviceEndpoints(ctx context.Context, c kclient.Client, app *v1.AppInstance
 		return nil, err
 	}
 
+	endpointSet := map[string]v1.Endpoint{}
 	for _, service := range serviceList.Items {
-		containerName := service.Labels[labels.AcornContainerName]
-		if containerName == "" {
+		targetName := service.Labels[labels.AcornContainerName]
+		if targetName == "" {
+			targetName = service.Labels[labels.AcornJobName]
+		}
+		if targetName == "" {
+			targetName = service.Labels[labels.AcornFunctionName]
+		}
+		if targetName == "" {
 			continue
 		}
 
@@ -53,44 +60,69 @@ func serviceEndpoints(ctx context.Context, c kclient.Client, app *v1.AppInstance
 					portNum := port.Port
 					if len(ingress.Ports) > 0 {
 						for _, ingressPort := range ingress.Ports {
-							endpoints = append(endpoints, v1.Endpoint{
-								Target:     containerName,
-								TargetPort: port.TargetPort.IntVal,
-								Address:    fmt.Sprintf("%s:%d", ingress.Hostname, ingressPort.Port),
-								Protocol:   protocol,
-							})
+							portProtocol := protocol
+							if ingressPort.Protocol != "" {
+								switch ingressPort.Protocol {
+								case corev1.ProtocolTCP:
+									portProtocol = v1.ProtocolTCP
+								case corev1.ProtocolUDP:
+									portProtocol = v1.ProtocolUDP
+								default:
+									continue
+								}
+							}
+							// Checking for ingressPort.Port == port.NodePort is a hack. It's not possible to check which port in status.LoadBalancer.Ingress
+							// matches which port in service.Spec.Ports. But in TCP port allocation in manager we always allocate the same port for NodePort and Port
+							// so that we can use this hack to match the ports.
+							if ingressPort.Port == port.Port || ingressPort.Port == port.NodePort {
+								ep := v1.Endpoint{
+									Target:     targetName,
+									TargetPort: port.TargetPort.IntVal,
+									Address:    fmt.Sprintf("%s:%d", ingress.Hostname, ingressPort.Port),
+									Protocol:   portProtocol,
+								}
+								endpointSet[endpointKey(ep)] = ep
+							}
 						}
 					} else {
-						endpoints = append(endpoints, v1.Endpoint{
-							Target:     containerName,
+						ep := v1.Endpoint{
+							Target:     targetName,
 							TargetPort: port.TargetPort.IntVal,
 							Address:    fmt.Sprintf("%s:%d", ingress.Hostname, portNum),
 							Protocol:   protocol,
-						})
+						}
+						endpointSet[endpointKey(ep)] = ep
 					}
 				} else if ingress.IP != "" {
-					endpoints = append(endpoints, v1.Endpoint{
-						Target:     containerName,
+					ep := v1.Endpoint{
+						Target:     targetName,
 						TargetPort: port.TargetPort.IntVal,
 						Address:    fmt.Sprintf("%s:%d", ingress.IP, port.Port),
 						Protocol:   protocol,
-					})
+					}
+					endpointSet[endpointKey(ep)] = ep
 				}
 			}
 
 			if len(service.Status.LoadBalancer.Ingress) == 0 {
-				endpoints = append(endpoints, v1.Endpoint{
-					Target:     containerName,
+				ep := v1.Endpoint{
+					Target:     targetName,
 					TargetPort: port.TargetPort.IntVal,
 					Address:    fmt.Sprintf("<Pending Ingress>:%d", port.Port),
 					Protocol:   protocol,
 					Pending:    true,
-				})
+				}
+				endpointSet[endpointKey(ep)] = ep
 			}
 		}
 	}
 
-	return
+	result := make([]v1.Endpoint, 0, len(endpointSet))
+	for _, ep := range endpointSet {
+		result = append(result, ep)
+	}
+
+	return result, nil
 }
 
 func ingressEndpoints(ctx context.Context, c kclient.Client, app *v1.AppInstance) (endpoints []v1.Endpoint, _ error) {
@@ -178,7 +210,7 @@ func (a *appStatusRenderer) readEndpoints() error {
 	return nil
 }
 
-func ingressTLSHosts(ctx context.Context, client kclient.Client, app *v1.AppInstance) (map[string]interface{}, error) {
+func ingressTLSHosts(ctx context.Context, client kclient.Client, app *v1.AppInstance) (map[string]struct{}, error) {
 	ingresses := &networkingv1.IngressList{}
 	err := client.List(ctx, ingresses, &kclient.ListOptions{
 		Namespace: app.Status.Namespace,
@@ -191,12 +223,12 @@ func ingressTLSHosts(ctx context.Context, client kclient.Client, app *v1.AppInst
 		return nil, err
 	}
 
-	ingressTLSHosts := map[string]interface{}{}
+	ingressTLSHosts := map[string]struct{}{}
 	for _, ingress := range ingresses.Items {
 		if ingress.Spec.TLS != nil {
 			for _, tls := range ingress.Spec.TLS {
 				for _, host := range tls.Hosts {
-					ingressTLSHosts[host] = nil
+					ingressTLSHosts[host] = struct{}{}
 				}
 			}
 		}
@@ -204,3 +236,7 @@ func ingressTLSHosts(ctx context.Context, client kclient.Client, app *v1.AppInst
 
 	return ingressTLSHosts, nil
 }
+
+func endpointKey(ep v1.Endpoint) string {
+	return fmt.Sprintf("%v://%v", ep.Protocol, ep.Address)
+}
