@@ -3,6 +3,7 @@ package appstatus
 import (
 	"fmt"
 	"strconv"
+	"strings"
 
 	"github.com/acorn-io/baaah/pkg/router"
 	"github.com/acorn-io/baaah/pkg/typed"
@@ -10,6 +11,7 @@ import (
 	"github.com/acorn-io/runtime/pkg/labels"
 	"github.com/acorn-io/runtime/pkg/publicname"
 	"github.com/acorn-io/runtime/pkg/ref"
+	"github.com/acorn-io/runtime/pkg/secrets"
 	corev1 "k8s.io/api/core/v1"
 	apierrors "k8s.io/apimachinery/pkg/api/errors"
 )
@@ -40,6 +42,7 @@ func (a *appStatusRenderer) readSecrets() error {
 		}
 
 		s := v1.SecretStatus{
+			Missing: existingStatus[secretName].Missing,
 			CommonStatus: v1.CommonStatus{
 				LinkOverride:          linkedSecret(a.app, secretName),
 				ErrorMessages:         existingStatus[secretName].LookupErrors,
@@ -48,6 +51,22 @@ func (a *appStatusRenderer) readSecrets() error {
 			},
 		}
 
+		if s.Missing && strings.HasPrefix(secretDef.Type, v1.SecretTypeCredentialPrefix) {
+			s.LoginRequired = true
+			s.TransitioningMessages = []string{fmt.Sprintf("missing: \"acorn login %s\" required", publicname.Get(a.app))}
+			a.app.Status.AppStatus.LoginRequired = true
+
+			instructionsData := secretDef.Params.GetData()["instructions"]
+			if instructions, _ := instructionsData.(string); instructions != "" {
+				result, err := secrets.NewInterpolator(a.ctx, a.c, a.app).Replace(instructions)
+				if err == nil {
+					s.LoginInstructions = result
+				} else {
+					s.LoginInstructions = instructions
+				}
+			}
+		}
+
 		secret := &corev1.Secret{}
 		if err := ref.Lookup(a.ctx, a.c, secret, a.app.Status.Namespace, secretName); apierrors.IsNotFound(err) {
 			a.app.Status.AppStatus.Secrets[secretName] = s
