@@ -19,17 +19,20 @@ import (
 	"github.com/acorn-io/runtime/pkg/controller/images"
 	"github.com/acorn-io/runtime/pkg/controller/ingress"
 	"github.com/acorn-io/runtime/pkg/controller/jobs"
+	"github.com/acorn-io/runtime/pkg/controller/local"
 	"github.com/acorn-io/runtime/pkg/controller/namespace"
 	"github.com/acorn-io/runtime/pkg/controller/networkpolicy"
 	"github.com/acorn-io/runtime/pkg/controller/permissions"
 	"github.com/acorn-io/runtime/pkg/controller/pvc"
 	"github.com/acorn-io/runtime/pkg/controller/quota"
+	"github.com/acorn-io/runtime/pkg/controller/resolvedofferings"
 	"github.com/acorn-io/runtime/pkg/controller/scheduling"
 	"github.com/acorn-io/runtime/pkg/controller/secrets"
 	"github.com/acorn-io/runtime/pkg/controller/service"
 	"github.com/acorn-io/runtime/pkg/controller/tls"
 	"github.com/acorn-io/runtime/pkg/event"
 	"github.com/acorn-io/runtime/pkg/labels"
+	"github.com/acorn-io/runtime/pkg/local/webhook"
 	"github.com/acorn-io/runtime/pkg/project"
 	"github.com/acorn-io/runtime/pkg/system"
 	"github.com/acorn-io/runtime/pkg/volume"
@@ -77,6 +80,7 @@ func routes(router *router.Router, cfg *rest.Config, registryTransport http.Roun
 	// DeploySpec will create the namespace, so ensure it runs before anything that requires a namespace
 	appHasNamespace := appRouter.Middleware(appdefinition.RequireNamespace, appdefinition.IgnoreTerminatingNamespace, appdefinition.FilterLabelsAndAnnotationsConfig)
 	appHasNamespace.HandlerFunc(defaults.Calculate)
+	appHasNamespace.HandlerFunc(resolvedofferings.Calculate)
 	appHasNamespace.HandlerFunc(scheduling.Calculate)
 	appHasNamespace.HandlerFunc(quota.EnsureQuotaRequest)
 	appHasNamespace.HandlerFunc(quota.WaitForAllocation)
@@ -153,5 +157,23 @@ func routes(router *router.Router, cfg *rest.Config, registryTransport http.Roun
 	devConfigRouter := router.Type(&corev1.ConfigMap{}).Namespace(system.Namespace).Name(system.DevConfigName)
 	devConfigRouter.HandlerFunc(config.PurgeDevConfig)
 
+	if system.IsLocal() {
+		svcHandler, err := local.NewHandler()
+		if err != nil {
+			return err
+		}
+		createFolder, err := local.NewCreateFolder()
+		if err != nil {
+			return err
+		}
+		if err := webhook.Server("0.0.0.0:8443"); err != nil {
+			return err
+		}
+		router.Type(&corev1.Pod{}).HandlerFunc(local.DeletePods)
+		router.Type(&corev1.Service{}).HandlerFunc(svcHandler.ProvisionPorts)
+		router.Type(&corev1.PersistentVolumeClaim{}).Handler(createFolder)
+		router.Type(&corev1.PersistentVolume{}).HandlerFunc(local.CleanupStorage)
+	}
+
 	return nil
 }
