@@ -6,6 +6,7 @@ import (
 	"fmt"
 	"io"
 	"os"
+	"slices"
 	"strings"
 	"sync"
 	"sync/atomic"
@@ -19,6 +20,7 @@ import (
 	"github.com/acorn-io/runtime/pkg/imagesource"
 	"github.com/acorn-io/runtime/pkg/labels"
 	"github.com/acorn-io/runtime/pkg/log"
+	"github.com/acorn-io/runtime/pkg/publicname"
 	"github.com/acorn-io/runtime/pkg/rulerequest"
 	"github.com/acorn-io/runtime/pkg/server/registry/apigroups/acorn/devsessions"
 	"github.com/acorn-io/z"
@@ -40,7 +42,7 @@ type Logger interface {
 }
 
 type AppStatusLogger interface {
-	AppStatus(ready bool, msg string)
+	AppStatus(ready bool, msg string, app *apiv1.App)
 }
 
 type Options struct {
@@ -70,26 +72,27 @@ type BuildStatus struct {
 	Message string
 }
 
-func (o *Options) complete() *Options {
+func (o *Options) complete(ctx context.Context, c client.Client) *Options {
 	var cp Options
 	if o != nil {
 		cp = *o
 	}
 	if cp.Logger == nil {
-		cp.Logger = log.DefaultLogger
+		cp.Logger = log.NewDefaultLogger(ctx, c)
 	}
 
 	return &cp
 }
 
 type watcher struct {
-	c            client.Client
-	imageAndArgs imagesource.ImageSource
-	trigger      chan struct{}
-	watching     []string
-	watchingTS   []time.Time
-	initOnce     sync.Once
-	logger       Logger
+	c               client.Client
+	imageAndArgs    imagesource.ImageSource
+	trigger         chan struct{}
+	dynamicWatching []string
+	watching        []string
+	watchingTS      []time.Time
+	initOnce        sync.Once
+	logger          Logger
 }
 
 func (w *watcher) Trigger() {
@@ -99,8 +102,25 @@ func (w *watcher) Trigger() {
 	}
 }
 
+func (w *watcher) addWatchFiles(files ...string) {
+	var changed bool
+	for _, file := range files {
+		if !slices.Contains(w.dynamicWatching, file) {
+			changed = true
+			w.dynamicWatching = append(w.dynamicWatching, file)
+		}
+	}
+	if changed {
+		w.Trigger()
+	}
+}
+
 func (w *watcher) readFiles(ctx context.Context) ([]string, error) {
-	return w.imageAndArgs.WatchFiles(ctx, w.c)
+	files, err := w.imageAndArgs.WatchFiles(ctx, w.c)
+	if err != nil {
+		return nil, err
+	}
+	return append(files, w.dynamicWatching...), nil
 }
 
 func (w *watcher) foundChanges() bool {
@@ -204,7 +224,7 @@ func buildStart(c chan<- BuildStatus) {
 }
 
 func buildLoop(ctx context.Context, c client.Client, hash clientHash, opts *Options) error {
-	opts = opts.complete()
+	opts = opts.complete(ctx, c)
 
 	var (
 		watcher = watcher{
@@ -252,7 +272,7 @@ func buildLoop(ctx context.Context, c client.Client, hash clientHash, opts *Opti
 
 		buildStart(opts.BuildStatus)
 		image, deployArgs, profiles, err := opts.ImageSource.GetImageAndDeployArgs(ctx, c)
-		if err == pflag.ErrHelp {
+		if errors.Is(err, pflag.ErrHelp) {
 			continue
 		} else if err != nil {
 			buildFailed(opts.BuildStatus, err.Error())
@@ -312,7 +332,7 @@ func buildLoop(ctx context.Context, c client.Client, hash clientHash, opts *Opti
 		opts.Run.Name = appName
 		eg, ctx := errgroup.WithContext(ctx)
 		eg.Go(func() error {
-			return DevPorts(ctx, c, appName)
+			return DevPorts(ctx, c, logger, appName)
 		})
 		eg.Go(func() error {
 			return LogLoop(ctx, c, appName, &client.LogOptions{
@@ -323,7 +343,7 @@ func buildLoop(ctx context.Context, c client.Client, hash clientHash, opts *Opti
 			return AppStatusLoop(ctx, c, logger, appName)
 		})
 		eg.Go(func() error {
-			return containerSyncLoop(ctx, c, appName, opts)
+			return containerSyncLoop(ctx, c, logger, appName, &watcher, opts)
 		})
 		eg.Go(func() error {
 			return appDeleteStop(ctx, c, logger, appName, cancel)
@@ -453,7 +473,7 @@ func appDeleteStop(ctx context.Context, c client.Client, logger AppStatusLogger,
 	w := objwatcher.New[*apiv1.App](wc)
 	_, err = w.ByName(ctx, c.GetNamespace(), appName, func(app *apiv1.App) (bool, error) {
 		if !app.DeletionTimestamp.IsZero() {
-			logger.AppStatus(false, fmt.Sprintf("app %s deleted, exiting", app.Name))
+			logger.AppStatus(false, fmt.Sprintf("app %s deleted, exiting", app.Name), app)
 			cancel()
 			return true, nil
 		}
@@ -493,6 +513,9 @@ func appStatusMessage(app *apiv1.App) (string, bool) {
 		// This is really only needed on the first run, before the controller runs
 		msg = "pending"
 	}
+	if app.Status.AppStatus.LoginRequired {
+		msg = fmt.Sprintf("\"acorn login %s\" required", publicname.Get(app))
+	}
 	return fmt.Sprintf("STATUS: ENDPOINTS[%s] HEALTHY[%s] UPTODATE[%s] %s",
 		app.Status.Columns.Endpoints,
 		app.Status.Columns.Healthy,
@@ -502,7 +525,7 @@ func appStatusMessage(app *apiv1.App) (string, bool) {
 
 func PrintAppStatus(app *apiv1.App, logger AppStatusLogger) {
 	msg, ready := appStatusMessage(app)
-	logger.AppStatus(ready, msg)
+	logger.AppStatus(ready, msg, app)
 }
 
 func AppStatusLoop(ctx context.Context, c client.Client, logger AppStatusLogger, appName string) error {
