@@ -129,6 +129,15 @@ func (i ImageSource) WatchFiles(ctx context.Context, c client.Client) ([]string,
 		return []string{file}, err
 	}
 
+	if entries, err := os.ReadDir(file); err == nil {
+		var result []string
+		for _, entry := range entries {
+			result = append(result, filepath.Join(file, entry.Name()))
+		}
+		result = append(result, files...)
+		return result, nil
+	}
+
 	return append([]string{file}, files...), nil
 }
 
@@ -150,6 +159,12 @@ func (i ImageSource) ResolveImageAndFile() (string, string, error) {
 		if isDir {
 			if st, err := os.Stat(filepath.Join(i.Image, "Acorndir")); err == nil && st.IsDir() {
 				i.File = filepath.Join(i.Image, "Acorndir")
+			} else if st, err := os.Stat(filepath.Join(i.Image, "Acornfile.d")); err == nil && st.IsDir() {
+				if _, err := os.Stat("Acornfile"); err == nil {
+					i.File = filepath.Join(i.Image, "Acornfile")
+				} else {
+					i.File = filepath.Join(i.Image, "Acornfile.d")
+				}
 			} else {
 				i.File = filepath.Join(i.Image, "Acornfile")
 			}
