@@ -12,9 +12,11 @@ import (
 	"strings"
 
 	"github.com/acorn-io/baaah/pkg/apply"
+	"github.com/acorn-io/baaah/pkg/merr"
 	"github.com/acorn-io/baaah/pkg/router"
 	"github.com/acorn-io/baaah/pkg/typed"
 	"github.com/acorn-io/baaah/pkg/watcher"
+	"github.com/acorn-io/baaah/pkg/yaml"
 	apiv1 "github.com/acorn-io/runtime/pkg/apis/api.acorn.io/v1"
 	"github.com/acorn-io/runtime/pkg/autoupgrade/validate"
 	"github.com/acorn-io/runtime/pkg/buildserver"
@@ -26,12 +28,11 @@ import (
 	"github.com/acorn-io/runtime/pkg/prompt"
 	"github.com/acorn-io/runtime/pkg/publish"
 	"github.com/acorn-io/runtime/pkg/roles"
+	"github.com/acorn-io/runtime/pkg/scheme"
 	"github.com/acorn-io/runtime/pkg/system"
 	"github.com/acorn-io/runtime/pkg/term"
 	"github.com/acorn-io/z"
 	"github.com/pterm/pterm"
-	"github.com/rancher/wrangler/pkg/merr"
-	"github.com/rancher/wrangler/pkg/yaml"
 	"github.com/sirupsen/logrus"
 	"golang.org/x/sync/errgroup"
 	appsv1 "k8s.io/api/apps/v1"
@@ -59,7 +60,9 @@ type Mode string
 
 type Options struct {
 	SkipChecks                          bool
+	IncludeLocalEnvResources            bool
 	OutputFormat                        string
+	Output                              io.Writer
 	APIServerReplicas                   *int
 	APIServerPodAnnotations             map[string]string
 	ControllerReplicas                  *int
@@ -75,6 +78,10 @@ func (o *Options) complete() *Options {
 		return o.complete()
 	}
 
+	if o.Output == nil {
+		o.Output = os.Stdout
+	}
+
 	if o.Progress == nil {
 		if o.Quiet {
 			o.Progress = &term.QuietBuilder{}
@@ -201,7 +208,7 @@ func Install(ctx context.Context, image string, opts *Options) error {
 
 	opts = opts.complete()
 	if opts.OutputFormat != "" {
-		return printObject(image, opts)
+		return PrintObjects(image, opts)
 	}
 
 	if err := upgradeFromV03(ctx, c); err != nil {
@@ -263,7 +270,7 @@ func Install(ctx context.Context, image string, opts *Options) error {
 	s.Success()
 
 	if installIngressController {
-		if err := installTraefik(ctx, opts.Progress, c, apply); err != nil {
+		if err := installTraefik(ctx, opts.Progress, apply); err != nil {
 			return err
 		}
 	}
@@ -272,7 +279,7 @@ func Install(ctx context.Context, image string, opts *Options) error {
 		return err
 	}
 
-	if err := waitAPI(ctx, opts.Progress, *opts.APIServerReplicas, image, c); err != nil {
+	if err := WaitAPI(ctx, opts.Progress, *opts.APIServerReplicas, image, c); err != nil {
 		return err
 	}
 
@@ -359,6 +366,50 @@ func TraefikResources() (result []kclient.Object, _ error) {
 	return objs, nil
 }
 
+func LocalResources() (result []kclient.Object, _ error) {
+	objs, err := objectsFromFile("local.yaml")
+	if err != nil {
+		return nil, err
+	}
+	for _, obj := range objs {
+		m, err := meta.Accessor(obj)
+		if err != nil {
+			return nil, err
+		}
+
+		labels := m.GetLabels()
+		if labels == nil {
+			labels = map[string]string{}
+		}
+		labels[labels2.AcornManaged] = "true"
+		m.SetLabels(labels)
+	}
+
+	return objs, nil
+}
+
+func CorednsResources() (result []kclient.Object, _ error) {
+	objs, err := objectsFromFile("coredns.yaml")
+	if err != nil {
+		return nil, err
+	}
+	for _, obj := range objs {
+		m, err := meta.Accessor(obj)
+		if err != nil {
+			return nil, err
+		}
+
+		labels := m.GetLabels()
+		if labels == nil {
+			labels = map[string]string{}
+		}
+		labels[labels2.AcornManaged] = "true"
+		m.SetLabels(labels)
+	}
+
+	return objs, nil
+}
+
 func missingIngressClass(ctx context.Context, client kclient.Client) (bool, error) {
 	ingressClassList := &networkingv1.IngressClassList{}
 	err := client.List(ctx, ingressClassList)
@@ -368,7 +419,7 @@ func missingIngressClass(ctx context.Context, client kclient.Client) (bool, erro
 	return len(ingressClassList.Items) <= 0, nil
 }
 
-func installTraefik(ctx context.Context, p progress.Builder, client kclient.WithWatch, apply apply.Apply) (err error) {
+func installTraefik(ctx context.Context, p progress.Builder, apply apply.Apply) (err error) {
 	pb := p.New("Installing Traefik Ingress Controller")
 	defer func() {
 		_ = pb.Fail(err)
@@ -435,7 +486,7 @@ func waitRegistry(ctx context.Context, p progress.Builder, image string, client
 	return s.Fail(waitDeployment(ctx, s, client, image, system.RegistryName, system.ImagesNamespace, 1))
 }
 
-func waitAPI(ctx context.Context, p progress.Builder, replicas int, image string, client kclient.WithWatch) error {
+func WaitAPI(ctx context.Context, p progress.Builder, replicas int, image string, client kclient.WithWatch) error {
 	s := p.New("Waiting for API server deployment to be available")
 	if err := waitDeployment(ctx, s, client, image, "acorn-api", system.Namespace, int32(replicas)); err != nil {
 		return s.Fail(err)
@@ -481,7 +532,7 @@ func resources(image string, opts *Options) ([]kclient.Object, error) {
 	objs = append(objs, namespace...)
 
 	deps, err := Deployments(image, *opts.APIServerReplicas, *opts.ControllerReplicas, *opts.Config.UseCustomCABundle,
-		opts.ControllerServiceAccountAnnotations, opts.APIServerPodAnnotations)
+		opts.ControllerServiceAccountAnnotations, opts.APIServerPodAnnotations, opts)
 	if err != nil {
 		return nil, err
 	}
@@ -496,7 +547,9 @@ func resources(image string, opts *Options) ([]kclient.Object, error) {
 	return objs, nil
 }
 
-func printObject(image string, opts *Options) error {
+func PrintObjects(image string, opts *Options) error {
+	opts = opts.complete()
+
 	objs, err := resources(image, opts)
 	if err != nil {
 		return err
@@ -511,14 +564,14 @@ func printObject(image string, opts *Options) error {
 		return enc.Encode(m)
 	}
 
-	data, err := yaml.Export(typed.MapSlice(objs, func(t kclient.Object) runtime.Object {
+	data, err := yaml.Export(scheme.Scheme, typed.MapSlice(objs, func(t kclient.Object) runtime.Object {
 		return t
 	})...)
 	if err != nil {
 		return err
 	}
 
-	_, err = os.Stdout.Write(data)
+	_, err = opts.Output.Write(data)
 	return err
 }
 
@@ -533,7 +586,7 @@ func applyDeployments(ctx context.Context, imageName string, apiServerReplicas,
 		return err
 	}
 
-	deps, err := Deployments(imageName, apiServerReplicas, controllerReplicas, useCustomCABundle, controllerSAAnnotations, apiPodAnnotations)
+	deps, err := Deployments(imageName, apiServerReplicas, controllerReplicas, useCustomCABundle, controllerSAAnnotations, apiPodAnnotations, nil)
 	if err != nil {
 		return err
 	}
@@ -573,7 +626,30 @@ func Namespace() ([]kclient.Object, error) {
 	return objectsFromFile("namespace.yaml")
 }
 
-func Deployments(runtimeImage string, apiServerReplicas, controllerReplicas int, useCustomCABundle bool, controllerSAAnnotations, apiPodAnnotations map[string]string) ([]kclient.Object, error) {
+func Deployments(runtimeImage string, apiServerReplicas, controllerReplicas int, useCustomCABundle bool, controllerSAAnnotations, apiPodAnnotations map[string]string, opts *Options) ([]kclient.Object, error) {
+	var objects []kclient.Object
+
+	// Do local resources first so that the webhook gets setup before anything else
+	if opts != nil && opts.IncludeLocalEnvResources {
+		objs, err := TraefikResources()
+		if err != nil {
+			return nil, err
+		}
+		objects = append(objects, objs...)
+
+		objs, err = CorednsResources()
+		if err != nil {
+			return nil, err
+		}
+		objects = append(objects, objs...)
+
+		objs, err = LocalResources()
+		if err != nil {
+			return nil, err
+		}
+		objects = append(objects, objs...)
+	}
+
 	apiServerObjects, err := objectsFromFile("apiserver.yaml")
 	if err != nil {
 		return nil, err
@@ -604,8 +680,8 @@ func Deployments(runtimeImage string, apiServerReplicas, controllerReplicas int,
 		return nil, err
 	}
 
-	var objects []kclient.Object
-	objects = append(apiServerObjects, controllerObjects...)
+	objects = append(objects, apiServerObjects...)
+	objects = append(objects, controllerObjects...)
 	if useCustomCABundle {
 		objects, err = replaceCABundleVolumes(objects)
 		if err != nil {
@@ -686,14 +762,20 @@ func replaceImage(image string, objs []kclient.Object) ([]kclient.Object, error)
 					"name":  "ACORN_IMAGE",
 					"value": image,
 				}
+				acornDockerImageEnv := map[string]any{
+					"name":  "ACORN_DOCKER_IMAGE",
+					"value": os.Getenv("ACORN_DOCKER_IMAGE"),
+				}
 				envs := container.(map[string]any)["env"]
 				if envs == nil {
-					container.(map[string]any)["env"] = []interface{}{acornImageEnv}
+					container.(map[string]any)["env"] = []interface{}{acornImageEnv, acornDockerImageEnv}
 				} else {
-					container.(map[string]any)["env"] = append(envs.([]interface{}), acornImageEnv)
+					container.(map[string]any)["env"] = append(envs.([]interface{}), acornImageEnv, acornDockerImageEnv)
 				}
-				if !strings.Contains(image, ":v") {
+				if !strings.Contains(image, ":v") && image != system.LocalImage {
 					container.(map[string]any)["imagePullPolicy"] = "Always"
+				} else {
+					container.(map[string]any)["imagePullPolicy"] = "IfNotPresent"
 				}
 			}
 			if err := unstructured.SetNestedSlice(ustr.Object, containers, "spec", "template", "spec", "containers"); err != nil {
