@@ -31,6 +31,7 @@ const (
 	AcornSecretSourceName                  = Prefix + "secret-source-name"
 	AcornSecretGenerated                   = Prefix + "secret-generated"
 	AcornContainerName                     = Prefix + "container-name"
+	AcornFunctionName                      = Prefix + "function-name"
 	AcornRouterName                        = Prefix + "router-name"
 	AcornJobName                           = Prefix + "job-name"
 	AcornAppImage                          = Prefix + "app-image"
@@ -61,6 +62,7 @@ const (
 	ProjectEnforcedQuotaAnnotation         = Prefix + "enforced-quota"
 	AcornPermissions                       = Prefix + "permissions"
 	AcornConfigHashAnnotation              = Prefix + "config-hash"
+	AcornContainerResolvedOfferings        = Prefix + "container-resolved-offerings"
 
 	IdentityPrefix                = "identity." + Prefix
 	AcornIdentityAccountServerURL = IdentityPrefix + "account-server-url"
@@ -158,6 +160,18 @@ func FilterUserDefined(appInstance *v1.AppInstance, allowedLabels, allowedAnnota
 		appInstance.Status.AppSpec.Containers[key] = c
 	}
 
+	for key, c := range appInstance.Status.AppSpec.Functions {
+		c.Labels = filter(c.Labels, allowedLabels)
+		c.Annotations = filter(c.Annotations, allowedAnnotations)
+		appInstance.Status.AppSpec.Functions[key] = c
+	}
+
+	for key, c := range appInstance.Status.AppSpec.Functions {
+		c.Labels = filter(c.Labels, allowedLabels)
+		c.Annotations = filter(c.Annotations, allowedAnnotations)
+		appInstance.Status.AppSpec.Functions[key] = c
+	}
+
 	for key, j := range appInstance.Status.AppSpec.Jobs {
 		j.Labels = filter(j.Labels, allowedLabels)
 		j.Annotations = filter(j.Annotations, allowedAnnotations)
