@@ -33,6 +33,8 @@ func productionProfile() apiv1.Config {
 	conf.ControllerCPU = z.Pointer("100m")
 	conf.APIServerMemory = z.Pointer("256Mi")
 	conf.APIServerCPU = z.Pointer("100m")
+	conf.IgnoreResourceRequirements = z.Pointer(false)
+	conf.AutoConfigureKarpenterDontEvictAnnotations = z.Pointer(true)
 
 	return conf
 }
