@@ -8,9 +8,8 @@ import (
 	"strconv"
 	"strings"
 
-	aml "github.com/acorn-io/aml/legacy"
-	"github.com/acorn-io/aml/legacy/pkg/replace"
 	"github.com/acorn-io/baaah/pkg/apply"
+	"github.com/acorn-io/baaah/pkg/merr"
 	"github.com/acorn-io/baaah/pkg/router"
 	v1 "github.com/acorn-io/runtime/pkg/apis/internal.acorn.io/v1"
 	"github.com/acorn-io/runtime/pkg/config"
@@ -20,11 +19,11 @@ import (
 	"github.com/acorn-io/runtime/pkg/labels"
 	"github.com/acorn-io/runtime/pkg/publicname"
 	"github.com/acorn-io/runtime/pkg/ref"
+	"github.com/acorn-io/runtime/pkg/replace"
 	"github.com/acorn-io/runtime/pkg/tags"
 	"github.com/acorn-io/runtime/pkg/volume"
 	"github.com/google/go-containerregistry/pkg/name"
 	"github.com/pkg/errors"
-	"github.com/rancher/wrangler/pkg/merr"
 	corev1 "k8s.io/api/core/v1"
 	apierrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -64,6 +63,7 @@ type Interpolator struct {
 	errs          *[]error
 	namespace     string
 	containerName string
+	functionName  string
 	jobName       string
 	serviceName   string
 }
@@ -94,6 +94,7 @@ func (i *Interpolator) ForJob(jobName string) *Interpolator {
 	cp.jobName = jobName
 	cp.containerName = ""
 	cp.serviceName = ""
+	cp.functionName = ""
 	return &cp
 }
 
@@ -102,6 +103,16 @@ func (i *Interpolator) ForContainer(containerName string) *Interpolator {
 	cp.jobName = ""
 	cp.serviceName = ""
 	cp.containerName = containerName
+	cp.functionName = ""
+	return &cp
+}
+
+func (i *Interpolator) ForFunction(functionName string) *Interpolator {
+	cp := *i
+	cp.jobName = ""
+	cp.serviceName = ""
+	cp.containerName = ""
+	cp.functionName = functionName
 	return &cp
 }
 
@@ -110,6 +121,7 @@ func (i *Interpolator) ForService(serviceName string) *Interpolator {
 	cp.jobName = ""
 	cp.serviceName = serviceName
 	cp.containerName = ""
+	cp.functionName = ""
 	return &cp
 }
 
@@ -120,6 +132,8 @@ func (i *Interpolator) Incomplete() bool {
 		return i.incomplete[i.containerName]
 	} else if i.serviceName != "" {
 		return i.incomplete[i.serviceName]
+	} else if i.functionName != "" {
+		return i.incomplete[i.functionName]
 	}
 	return len(i.incomplete) > 0
 }
@@ -226,6 +240,19 @@ func (i *Interpolator) GetProjectName() (string, error) {
 	return name, nil
 }
 
+func (i *Interpolator) GetRegion() (string, error) {
+	if region := i.app.GetRegion(); region != "" {
+		return region, nil
+	}
+
+	project := &v1.ProjectInstance{}
+	if err := i.client.Get(i.ctx, router.Key("", i.app.Namespace), project); err != nil {
+		return "", err
+	}
+
+	return project.Status.DefaultRegion, nil
+}
+
 func (i *Interpolator) resolveApp(keyName string) (string, bool, error) {
 	switch strings.ToLower(keyName) {
 	case "name":
@@ -255,6 +282,9 @@ func (i *Interpolator) resolveApp(keyName string) (string, bool, error) {
 	case "externalid":
 		externalID, err := i.getExternalID()
 		return externalID, true, err
+	case "region":
+		region, err := i.GetRegion()
+		return region, true, err
 	}
 	return "", false, nil
 }
@@ -339,7 +369,7 @@ func (i *Interpolator) serviceProperty(svc *v1.ServiceInstance, prop string, ext
 		}
 		return "", &ErrInterpolation{
 			ExpressionError: v1.ExpressionError{
-				Error: fmt.Sprintf("endpoint on service [%s] undefined", svc.Name),
+				Error: fmt.Sprintf("endpoint on service [%s] undefined, check that at least one port as marked as published", svc.Name),
 			},
 		}
 	case "address", "host", "hostname":
@@ -364,7 +394,7 @@ func (i *Interpolator) serviceProperty(svc *v1.ServiceInstance, prop string, ext
 		return "", fmt.Errorf("failed to find port [%s] defined on service [%s]", extra[0], svc.Name)
 	case "data":
 		expr := "@{" + strings.Join(extra, ".") + "}"
-		v, err := aml.Interpolate(svc.Spec.Data, expr)
+		v, err := replace.Interpolate(svc.Spec.Data, expr)
 		return v, err
 	default:
 		return "", fmt.Errorf("invalid property [%s] to lookup on service [%s]", prop, svc.Name)
@@ -500,6 +530,11 @@ func (i *Interpolator) saveError(err error) {
 		c := i.app.Status.AppStatus.Containers[i.containerName]
 		c.ExpressionErrors = append(c.ExpressionErrors, exprError)
 		i.app.Status.AppStatus.Containers[i.containerName] = c
+	} else if i.functionName != "" {
+		i.incomplete[i.functionName] = true
+		c := i.app.Status.AppStatus.Functions[i.functionName]
+		c.ExpressionErrors = append(c.ExpressionErrors, exprError)
+		i.app.Status.AppStatus.Functions[i.functionName] = c
 	} else if i.jobName != "" {
 		i.incomplete[i.jobName] = true
 		c := i.app.Status.AppStatus.Jobs[i.jobName]
@@ -520,9 +555,25 @@ func (i *Interpolator) getContainerOrJobName() string {
 	if i.containerName != "" {
 		return i.containerName
 	}
+	if i.functionName != "" {
+		return i.functionName
+	}
 	return i.jobName
 }
 
+// HasUnescapedDot checks if a string contains an unescaped dot (i.e., a dot not escaped by a backslash).
+func HasUnescapedDot(s string) bool {
+	for i := 0; i < len(s); i++ {
+		if s[i] == '.' {
+			// Match if it's the first character or not escaped by a backslash
+			if i == 0 || s[i-1] != '\\' {
+				return true
+			}
+		}
+	}
+	return false
+}
+
 func (i *Interpolator) ToEnv(key, value string) (corev1.EnvVar, bool) {
 	prefix := i.getContainerOrJobName()
 	key = strings.TrimPrefix(key, prefix+".")
@@ -533,7 +584,7 @@ func (i *Interpolator) ToEnv(key, value string) (corev1.EnvVar, bool) {
 		return corev1.EnvVar{
 			Name:  key,
 			Value: value,
-		}, !strings.Contains(key, ".")
+		}, !HasUnescapedDot(key)
 	}
 
 	newValue, err := i.Replace(value)
@@ -542,13 +593,13 @@ func (i *Interpolator) ToEnv(key, value string) (corev1.EnvVar, bool) {
 		return corev1.EnvVar{
 			Name:  newKey,
 			Value: value,
-		}, !strings.Contains(key, ".")
+		}, !HasUnescapedDot(key)
 	}
 	if value == newValue {
 		return corev1.EnvVar{
 			Name:  newKey,
 			Value: value,
-		}, !strings.Contains(newKey, ".")
+		}, !HasUnescapedDot(newKey)
 	}
 
 	return corev1.EnvVar{
@@ -561,7 +612,7 @@ func (i *Interpolator) ToEnv(key, value string) (corev1.EnvVar, bool) {
 				Key: i.addContent(newValue),
 			},
 		},
-	}, !strings.Contains(newKey, ".")
+	}, !HasUnescapedDot(newKey)
 }
 
 func (i *Interpolator) Objects() []kclient.Object {
