@@ -4,10 +4,8 @@ import (
 	"net/http"
 
 	"github.com/acorn-io/mink/pkg/stores"
-	"github.com/acorn-io/mink/pkg/strategy/remote"
 	"github.com/acorn-io/mink/pkg/strategy/translation"
 	apiv1 "github.com/acorn-io/runtime/pkg/apis/api.acorn.io/v1"
-	v1 "github.com/acorn-io/runtime/pkg/apis/internal.acorn.io/v1"
 	"github.com/acorn-io/runtime/pkg/client"
 	"github.com/acorn-io/runtime/pkg/event"
 	"github.com/acorn-io/runtime/pkg/publicname"
@@ -18,12 +16,12 @@ import (
 )
 
 func NewStorage(c kclient.WithWatch, clientFactory *client.Factory, recorder event.Recorder, transport http.RoundTripper, middlewares ...middleware.CompleteStrategy) rest.Storage {
-	remoteResource := remote.NewRemote(&v1.AppInstance{}, c)
-	strategy := translation.NewSimpleTranslationStrategy(&Translator{}, remoteResource)
-	strategy = publicname.NewStrategy(strategy)
+	strategy := newAppInstanceStrategy(c)
+	strategy = publicname.NewStrategy(
+		translation.NewSimpleTranslationStrategy(&translator{}, strategy),
+	)
 	strategy = newEventRecordingStrategy(strategy, recorder)
 	strategy = middleware.ForCompleteStrategy(strategy, middlewares...)
-
 	validator := NewValidator(c, clientFactory, strategy, transport)
 
 	return stores.NewBuilder(c.Scheme(), &apiv1.App{}).
