@@ -258,11 +258,6 @@ func (s *Validator) ValidateUpdate(ctx context.Context, obj, old runtime.Object)
 		}
 	}
 
-	if oldParams.Status.GetDevMode() {
-		result = append(result, field.Invalid(field.NewPath("status", "devSession"), "", "app is locked by dev session"))
-		return result
-	}
-
 	if newParams.Spec.Region != oldParams.Spec.Region && newParams.Spec.Region != oldParams.Status.Defaults.Region {
 		result = append(result, field.Invalid(field.NewPath("spec", "region"), newParams.Spec.Region, "cannot change region"))
 		return result
@@ -809,6 +804,12 @@ func (s *Validator) getWorkloads(details *apiv1.ImageDetails) (map[string]v1.Con
 			result[sidecarWorkload] = sidecarContainer
 		}
 	}
+	for workload, function := range details.AppSpec.Functions {
+		result[workload] = function
+		for sidecarWorkload, sidecarContainer := range function.Sidecars {
+			result[sidecarWorkload] = sidecarContainer
+		}
+	}
 	for workload, container := range details.AppSpec.Jobs {
 		result[workload] = container
 	}
