@@ -2,6 +2,7 @@ package secrets
 
 import (
 	"context"
+	"strings"
 
 	apiv1 "github.com/acorn-io/runtime/pkg/apis/api.acorn.io/v1"
 	v1 "github.com/acorn-io/runtime/pkg/apis/internal.acorn.io/v1"
@@ -16,7 +17,7 @@ type Validator struct {
 func (v *Validator) Validate(ctx context.Context, obj runtime.Object) (result field.ErrorList) {
 	sec := obj.(*apiv1.Secret)
 	if sec.Type != "" {
-		if !v1.SecretTypes[corev1.SecretType(v1.SecretTypePrefix+sec.Type)] {
+		if !v1.SecretTypes[corev1.SecretType(v1.SecretTypePrefix+sec.Type)] && !strings.HasPrefix(sec.Type, v1.SecretTypeCredentialPrefix) {
 			result = append(result, field.Invalid(field.NewPath("type"), sec.Type, "Invalid secret type"))
 		}
 	}
