@@ -7,7 +7,6 @@ import (
 	"strconv"
 
 	"github.com/acorn-io/baaah/pkg/apply"
-	"github.com/acorn-io/baaah/pkg/name"
 	"github.com/acorn-io/baaah/pkg/typed"
 	v1 "github.com/acorn-io/runtime/pkg/apis/internal.acorn.io/v1"
 	"github.com/acorn-io/runtime/pkg/jobs"
@@ -124,8 +123,11 @@ func serviceNames(appInstance *v1.AppInstance) sets.Set[string] {
 	for k := range appInstance.Status.AppSpec.Containers {
 		result.Insert(k)
 	}
+	for k := range appInstance.Status.AppSpec.Functions {
+		result.Insert(k)
+	}
 	for k := range appInstance.Status.AppSpec.Jobs {
-		result.Insert(jobServiceName(k))
+		result.Insert(k)
 	}
 	for k := range appInstance.Status.AppSpec.Routers {
 		result.Insert(k)
@@ -302,6 +304,47 @@ func forContainers(interpolator *secrets.Interpolator, appInstance *v1.AppInstan
 	return
 }
 
+func forFunctions(appInstance *v1.AppInstance) (result []kclient.Object) {
+	for _, entry := range typed.Sorted(appInstance.Status.AppSpec.Functions) {
+		functionName, function := entry.Key, entry.Value
+
+		if ports2.IsLinked(appInstance, functionName) {
+			continue
+		}
+
+		ports := ports2.FunctionPortDefs(false)
+
+		result = append(result, &v1.ServiceInstance{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      functionName,
+				Namespace: appInstance.Status.Namespace,
+				Labels: labels.Managed(appInstance,
+					labels.AcornPublicName, publicname.ForChild(appInstance, functionName),
+					labels.AcornFunctionName, functionName),
+				Annotations: map[string]string{
+					labels.AcornAppGeneration:        strconv.FormatInt(appInstance.Generation, 10),
+					labels.AcornConfigHashAnnotation: appInstance.Status.AppStatus.Containers[functionName].ConfigHash,
+				},
+			},
+			Spec: v1.ServiceInstanceSpec{
+				AppName:      appInstance.Name,
+				AppNamespace: appInstance.Namespace,
+				PublishMode:  publishMode(appInstance),
+				Publish:      ports2.PortPublishForService(functionName, appInstance.Spec.Publish),
+				Labels: labels.Merge(labels.Managed(appInstance, labels.AcornFunctionName, functionName),
+					labels.GatherScoped(functionName, v1.LabelTypeFunction,
+						appInstance.Status.AppSpec.Labels, function.Labels, appInstance.Spec.Labels)),
+				Annotations: labels.GatherScoped(functionName, v1.LabelTypeFunction,
+					appInstance.Status.AppSpec.Annotations, function.Annotations, appInstance.Spec.Annotations),
+				Ports:    ports,
+				Function: functionName,
+			},
+		})
+	}
+
+	return
+}
+
 func forJobs(interpolator *secrets.Interpolator, appInstance *v1.AppInstance) (result []kclient.Object) {
 	for _, entry := range typed.Sorted(appInstance.Status.AppSpec.Jobs) {
 		jobName, job := entry.Key, entry.Value
@@ -340,7 +383,7 @@ func forJobs(interpolator *secrets.Interpolator, appInstance *v1.AppInstance) (r
 
 		result = append(result, &v1.ServiceInstance{
 			ObjectMeta: metav1.ObjectMeta{
-				Name:      jobServiceName(jobName),
+				Name:      jobName,
 				Namespace: appInstance.Status.Namespace,
 				Labels: labels.Managed(appInstance,
 					labels.AcornPublicName, publicname.ForChild(appInstance, jobName),
@@ -458,6 +501,7 @@ func ToAcornServices(ctx context.Context, c kclient.Client, interpolator *secret
 	result = append(result, objs...)
 	result = append(result, forAcorns(appInstance)...)
 	result = append(result, forContainers(interpolator, appInstance)...)
+	result = append(result, forFunctions(appInstance)...)
 	result = append(result, forJobs(interpolator, appInstance)...)
 
 	routers, err := forRouters(appInstance)
@@ -541,7 +585,3 @@ func getUngranted(appInstance *v1.AppInstance, service *v1.ServiceInstance) []v1
 
 	return ungranted
 }
-
-func jobServiceName(jobName string) string {
-	return name.SafeConcatName(jobName, "job")
-}
